/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtCore.h"

#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQt.cpp"


static sipEnumMemberDef enummembers_Qt[] = {
    {sipName_AA_CompressHighFrequencyEvents, static_cast<int>( ::Qt::AA_CompressHighFrequencyEvents), 354},
    {sipName_AA_CompressTabletEvents, static_cast<int>( ::Qt::AA_CompressTabletEvents), 354},
    {sipName_AA_DisableHighDpiScaling, static_cast<int>( ::Qt::AA_DisableHighDpiScaling), 354},
    {sipName_AA_DisableNativeVirtualKeyboard, static_cast<int>( ::Qt::AA_DisableNativeVirtualKeyboard), 354},
    {sipName_AA_DisableSessionManager, static_cast<int>( ::Qt::AA_DisableSessionManager), 354},
    {sipName_AA_DisableShaderDiskCache, static_cast<int>( ::Qt::AA_DisableShaderDiskCache), 354},
    {sipName_AA_DisableWindowContextHelpButton, static_cast<int>( ::Qt::AA_DisableWindowContextHelpButton), 354},
    {sipName_AA_DontCheckOpenGLContextThreadAffinity, static_cast<int>( ::Qt::AA_DontCheckOpenGLContextThreadAffinity), 354},
    {sipName_AA_DontCreateNativeWidgetSiblings, static_cast<int>( ::Qt::AA_DontCreateNativeWidgetSiblings), 354},
    {sipName_AA_DontShowIconsInMenus, static_cast<int>( ::Qt::AA_DontShowIconsInMenus), 354},
    {sipName_AA_DontShowShortcutsInContextMenus, static_cast<int>( ::Qt::AA_DontShowShortcutsInContextMenus), 354},
    {sipName_AA_DontUseNativeDialogs, static_cast<int>( ::Qt::AA_DontUseNativeDialogs), 354},
    {sipName_AA_DontUseNativeMenuBar, static_cast<int>( ::Qt::AA_DontUseNativeMenuBar), 354},
    {sipName_AA_EnableHighDpiScaling, static_cast<int>( ::Qt::AA_EnableHighDpiScaling), 354},
    {sipName_AA_ForceRasterWidgets, static_cast<int>( ::Qt::AA_ForceRasterWidgets), 354},
    {sipName_AA_ImmediateWidgetCreation, static_cast<int>( ::Qt::AA_ImmediateWidgetCreation), 354},
    {sipName_AA_MSWindowsUseDirect3DByDefault, static_cast<int>( ::Qt::AA_MSWindowsUseDirect3DByDefault), 354},
    {sipName_AA_MacDontSwapCtrlAndMeta, static_cast<int>( ::Qt::AA_MacDontSwapCtrlAndMeta), 354},
    {sipName_AA_MacPluginApplication, static_cast<int>( ::Qt::AA_MacPluginApplication), 354},
    {sipName_AA_NativeWindows, static_cast<int>( ::Qt::AA_NativeWindows), 354},
    {sipName_AA_PluginApplication, static_cast<int>( ::Qt::AA_PluginApplication), 354},
    {sipName_AA_SetPalette, static_cast<int>( ::Qt::AA_SetPalette), 354},
    {sipName_AA_ShareOpenGLContexts, static_cast<int>( ::Qt::AA_ShareOpenGLContexts), 354},
    {sipName_AA_SynthesizeMouseForUnhandledTabletEvents, static_cast<int>( ::Qt::AA_SynthesizeMouseForUnhandledTabletEvents), 354},
    {sipName_AA_SynthesizeMouseForUnhandledTouchEvents, static_cast<int>( ::Qt::AA_SynthesizeMouseForUnhandledTouchEvents), 354},
    {sipName_AA_SynthesizeTouchForUnhandledMouseEvents, static_cast<int>( ::Qt::AA_SynthesizeTouchForUnhandledMouseEvents), 354},
    {sipName_AA_Use96Dpi, static_cast<int>( ::Qt::AA_Use96Dpi), 354},
    {sipName_AA_UseDesktopOpenGL, static_cast<int>( ::Qt::AA_UseDesktopOpenGL), 354},
    {sipName_AA_UseHighDpiPixmaps, static_cast<int>( ::Qt::AA_UseHighDpiPixmaps), 354},
    {sipName_AA_UseOpenGLES, static_cast<int>( ::Qt::AA_UseOpenGLES), 354},
    {sipName_AA_UseSoftwareOpenGL, static_cast<int>( ::Qt::AA_UseSoftwareOpenGL), 354},
    {sipName_AA_UseStyleSheetPropagationInWidgetStyles, static_cast<int>( ::Qt::AA_UseStyleSheetPropagationInWidgetStyles), 354},
    {sipName_AA_X11InitThreads, static_cast<int>( ::Qt::AA_X11InitThreads), 354},
    {sipName_ALT, static_cast<int>( ::Qt::ALT), 412},
    {sipName_AbsoluteSize, static_cast<int>( ::Qt::AbsoluteSize), 431},
    {sipName_AccessibleDescriptionRole, static_cast<int>( ::Qt::AccessibleDescriptionRole), 400},
    {sipName_AccessibleTextRole, static_cast<int>( ::Qt::AccessibleTextRole), 400},
    {sipName_ActionMask, static_cast<int>( ::Qt::ActionMask), 376},
    {sipName_ActionsContextMenu, static_cast<int>( ::Qt::ActionsContextMenu), 367},
    {sipName_ActiveWindowFocusReason, static_cast<int>( ::Qt::ActiveWindowFocusReason), 386},
    {sipName_AddToSelection, static_cast<int>( ::Qt::AddToSelection), 404},
    {sipName_AlignAbsolute, static_cast<int>( ::Qt::AlignAbsolute), 352},
    {sipName_AlignBaseline, static_cast<int>( ::Qt::AlignBaseline), 352},
    {sipName_AlignBottom, static_cast<int>( ::Qt::AlignBottom), 352},
    {sipName_AlignCenter, static_cast<int>( ::Qt::AlignCenter), 352},
    {sipName_AlignHCenter, static_cast<int>( ::Qt::AlignHCenter), 352},
    {sipName_AlignHorizontal_Mask, static_cast<int>( ::Qt::AlignHorizontal_Mask), 352},
    {sipName_AlignJustify, static_cast<int>( ::Qt::AlignJustify), 352},
    {sipName_AlignLeading, static_cast<int>( ::Qt::AlignLeading), 352},
    {sipName_AlignLeft, static_cast<int>( ::Qt::AlignLeft), 352},
    {sipName_AlignRight, static_cast<int>( ::Qt::AlignRight), 352},
    {sipName_AlignTop, static_cast<int>( ::Qt::AlignTop), 352},
    {sipName_AlignTrailing, static_cast<int>( ::Qt::AlignTrailing), 352},
    {sipName_AlignVCenter, static_cast<int>( ::Qt::AlignVCenter), 352},
    {sipName_AlignVertical_Mask, static_cast<int>( ::Qt::AlignVertical_Mask), 352},
    {sipName_AllButtons, static_cast<int>( ::Qt::AllButtons), 413},
    {sipName_AllDockWidgetAreas, static_cast<int>( ::Qt::AllDockWidgetAreas), 374},
    {sipName_AllToolBarAreas, static_cast<int>( ::Qt::AllToolBarAreas), 442},
    {sipName_AltModifier, static_cast<int>( ::Qt::AltModifier), 406},
    {sipName_AnchorBottom, static_cast<int>( ::Qt::AnchorBottom), 353},
    {sipName_AnchorHorizontalCenter, static_cast<int>( ::Qt::AnchorHorizontalCenter), 353},
    {sipName_AnchorLeft, static_cast<int>( ::Qt::AnchorLeft), 353},
    {sipName_AnchorRight, static_cast<int>( ::Qt::AnchorRight), 353},
    {sipName_AnchorTop, static_cast<int>( ::Qt::AnchorTop), 353},
    {sipName_AnchorVerticalCenter, static_cast<int>( ::Qt::AnchorVerticalCenter), 353},
    {sipName_ApplicationActive, static_cast<int>( ::Qt::ApplicationActive), 355},
    {sipName_ApplicationHidden, static_cast<int>( ::Qt::ApplicationHidden), 355},
    {sipName_ApplicationInactive, static_cast<int>( ::Qt::ApplicationInactive), 355},
    {sipName_ApplicationModal, static_cast<int>( ::Qt::ApplicationModal), 453},
    {sipName_ApplicationShortcut, static_cast<int>( ::Qt::ApplicationShortcut), 429},
    {sipName_ApplicationSuspended, static_cast<int>( ::Qt::ApplicationSuspended), 355},
    {sipName_ArrowCursor, static_cast<int>( ::Qt::ArrowCursor), 371},
    {sipName_AscendingOrder, static_cast<int>( ::Qt::AscendingOrder), 432},
    {sipName_AutoColor, static_cast<int>( ::Qt::AutoColor), 394},
    {sipName_AutoConnection, static_cast<int>( ::Qt::AutoConnection), 366},
    {sipName_AutoDither, static_cast<int>( ::Qt::AutoDither), 394},
    {sipName_AutoText, static_cast<int>( ::Qt::AutoText), 436},
    {sipName_AvoidDither, static_cast<int>( ::Qt::AvoidDither), 394},
    {sipName_BDiagPattern, static_cast<int>( ::Qt::BDiagPattern), 361},
    {sipName_BackButton, static_cast<int>( ::Qt::BackButton), 413},
    {sipName_BackgroundColorRole, static_cast<int>( ::Qt::BackgroundColorRole), 400},
    {sipName_BackgroundRole, static_cast<int>( ::Qt::BackgroundRole), 400},
    {sipName_BacktabFocusReason, static_cast<int>( ::Qt::BacktabFocusReason), 386},
    {sipName_BeginNativeGesture, static_cast<int>( ::Qt::BeginNativeGesture), 418},
    {sipName_BevelJoin, static_cast<int>( ::Qt::BevelJoin), 423},
    {sipName_BitmapCursor, static_cast<int>( ::Qt::BitmapCursor), 371},
    {sipName_BlankCursor, static_cast<int>( ::Qt::BlankCursor), 371},
    {sipName_BlockingQueuedConnection, static_cast<int>( ::Qt::BlockingQueuedConnection), 366},
    {sipName_BottomDockWidgetArea, static_cast<int>( ::Qt::BottomDockWidgetArea), 374},
    {sipName_BottomEdge, static_cast<int>( ::Qt::BottomEdge), 378},
    {sipName_BottomLeftCorner, static_cast<int>( ::Qt::BottomLeftCorner), 369},
    {sipName_BottomLeftSection, static_cast<int>( ::Qt::BottomLeftSection), 452},
    {sipName_BottomRightCorner, static_cast<int>( ::Qt::BottomRightCorner), 369},
    {sipName_BottomRightSection, static_cast<int>( ::Qt::BottomRightSection), 452},
    {sipName_BottomSection, static_cast<int>( ::Qt::BottomSection), 452},
    {sipName_BottomToolBarArea, static_cast<int>( ::Qt::BottomToolBarArea), 442},
    {sipName_BusyCursor, static_cast<int>( ::Qt::BusyCursor), 371},
    {sipName_BypassGraphicsProxyWidget, static_cast<int>( ::Qt::BypassGraphicsProxyWidget), 456},
    {sipName_BypassWindowManagerHint, static_cast<int>( ::Qt::BypassWindowManagerHint), 456},
    {sipName_CTRL, static_cast<int>( ::Qt::CTRL), 412},
    {sipName_CaseInsensitive, static_cast<int>( ::Qt::CaseInsensitive), 362},
    {sipName_CaseSensitive, static_cast<int>( ::Qt::CaseSensitive), 362},
    {sipName_Ceil, static_cast<int>(::Qt::HighDpiScaleFactorRoundingPolicy::Ceil), 392},
    {sipName_CheckStateRole, static_cast<int>( ::Qt::CheckStateRole), 400},
    {sipName_Checked, static_cast<int>( ::Qt::Checked), 363},
    {sipName_ChecksumIso3309, static_cast<int>( ::Qt::ChecksumIso3309), 364},
    {sipName_ChecksumItuV41, static_cast<int>( ::Qt::ChecksumItuV41), 364},
    {sipName_ClickFocus, static_cast<int>( ::Qt::ClickFocus), 385},
    {sipName_ClosedHandCursor, static_cast<int>( ::Qt::ClosedHandCursor), 371},
    {sipName_CoarseTimer, static_cast<int>( ::Qt::CoarseTimer), 441},
    {sipName_ColorOnly, static_cast<int>( ::Qt::ColorOnly), 394},
    {sipName_ConicalGradientPattern, static_cast<int>( ::Qt::ConicalGradientPattern), 361},
    {sipName_ContainsItemBoundingRect, static_cast<int>( ::Qt::ContainsItemBoundingRect), 403},
    {sipName_ContainsItemShape, static_cast<int>( ::Qt::ContainsItemShape), 403},
    {sipName_ControlModifier, static_cast<int>( ::Qt::ControlModifier), 406},
    {sipName_CopyAction, static_cast<int>( ::Qt::CopyAction), 376},
    {sipName_CoverWindow, static_cast<int>( ::Qt::CoverWindow), 456},
    {sipName_CrossCursor, static_cast<int>( ::Qt::CrossCursor), 371},
    {sipName_CrossPattern, static_cast<int>( ::Qt::CrossPattern), 361},
    {sipName_CustomContextMenu, static_cast<int>( ::Qt::CustomContextMenu), 367},
    {sipName_CustomCursor, static_cast<int>( ::Qt::CustomCursor), 371},
    {sipName_CustomDashLine, static_cast<int>( ::Qt::CustomDashLine), 424},
    {sipName_CustomGesture, static_cast<int>( ::Qt::CustomGesture), 390},
    {sipName_CustomizeWindowHint, static_cast<int>( ::Qt::CustomizeWindowHint), 456},
    {sipName_DashDotDotLine, static_cast<int>( ::Qt::DashDotDotLine), 424},
    {sipName_DashDotLine, static_cast<int>( ::Qt::DashDotLine), 424},
    {sipName_DashLine, static_cast<int>( ::Qt::DashLine), 424},
    {sipName_DecorationRole, static_cast<int>( ::Qt::DecorationRole), 400},
    {sipName_DefaultContextMenu, static_cast<int>( ::Qt::DefaultContextMenu), 367},
    {sipName_DefaultLocaleLongDate, static_cast<int>( ::Qt::DefaultLocaleLongDate), 372},
    {sipName_DefaultLocaleShortDate, static_cast<int>( ::Qt::DefaultLocaleShortDate), 372},
    {sipName_Dense1Pattern, static_cast<int>( ::Qt::Dense1Pattern), 361},
    {sipName_Dense2Pattern, static_cast<int>( ::Qt::Dense2Pattern), 361},
    {sipName_Dense3Pattern, static_cast<int>( ::Qt::Dense3Pattern), 361},
    {sipName_Dense4Pattern, static_cast<int>( ::Qt::Dense4Pattern), 361},
    {sipName_Dense5Pattern, static_cast<int>( ::Qt::Dense5Pattern), 361},
    {sipName_Dense6Pattern, static_cast<int>( ::Qt::Dense6Pattern), 361},
    {sipName_Dense7Pattern, static_cast<int>( ::Qt::Dense7Pattern), 361},
    {sipName_DescendingOrder, static_cast<int>( ::Qt::DescendingOrder), 432},
    {sipName_Desktop, static_cast<int>( ::Qt::Desktop), 456},
    {sipName_DeviceCoordinates, static_cast<int>( ::Qt::DeviceCoordinates), 368},
    {sipName_DiagCrossPattern, static_cast<int>( ::Qt::DiagCrossPattern), 361},
    {sipName_Dialog, static_cast<int>( ::Qt::Dialog), 456},
    {sipName_DiffuseAlphaDither, static_cast<int>( ::Qt::DiffuseAlphaDither), 394},
    {sipName_DiffuseDither, static_cast<int>( ::Qt::DiffuseDither), 394},
    {sipName_DirectConnection, static_cast<int>( ::Qt::DirectConnection), 366},
    {sipName_DisplayRole, static_cast<int>( ::Qt::DisplayRole), 400},
    {sipName_DockWidgetArea_Mask, static_cast<int>( ::Qt::DockWidgetArea_Mask), 374},
    {sipName_DontStartGestureOnChildren, static_cast<int>( ::Qt::DontStartGestureOnChildren), 387},
    {sipName_DotLine, static_cast<int>( ::Qt::DotLine), 424},
    {sipName_DownArrow, static_cast<int>( ::Qt::DownArrow), 357},
    {sipName_DragCopyCursor, static_cast<int>( ::Qt::DragCopyCursor), 371},
    {sipName_DragLinkCursor, static_cast<int>( ::Qt::DragLinkCursor), 371},
    {sipName_DragMoveCursor, static_cast<int>( ::Qt::DragMoveCursor), 371},
    {sipName_Drawer, static_cast<int>( ::Qt::Drawer), 456},
    {sipName_EditRole, static_cast<int>( ::Qt::EditRole), 400},
    {sipName_ElideLeft, static_cast<int>( ::Qt::ElideLeft), 434},
    {sipName_ElideMiddle, static_cast<int>( ::Qt::ElideMiddle), 434},
    {sipName_ElideNone, static_cast<int>( ::Qt::ElideNone), 434},
    {sipName_ElideRight, static_cast<int>( ::Qt::ElideRight), 434},
    {sipName_EndNativeGesture, static_cast<int>( ::Qt::EndNativeGesture), 418},
    {sipName_EnterKeyDefault, static_cast<int>( ::Qt::EnterKeyDefault), 380},
    {sipName_EnterKeyDone, static_cast<int>( ::Qt::EnterKeyDone), 380},
    {sipName_EnterKeyGo, static_cast<int>( ::Qt::EnterKeyGo), 380},
    {sipName_EnterKeyNext, static_cast<int>( ::Qt::EnterKeyNext), 380},
    {sipName_EnterKeyPrevious, static_cast<int>( ::Qt::EnterKeyPrevious), 380},
    {sipName_EnterKeyReturn, static_cast<int>( ::Qt::EnterKeyReturn), 380},
    {sipName_EnterKeySearch, static_cast<int>( ::Qt::EnterKeySearch), 380},
    {sipName_EnterKeySend, static_cast<int>( ::Qt::EnterKeySend), 380},
    {sipName_ExactHit, static_cast<int>( ::Qt::ExactHit), 393},
    {sipName_ExtraButton1, static_cast<int>( ::Qt::ExtraButton1), 413},
    {sipName_ExtraButton10, static_cast<int>( ::Qt::ExtraButton10), 413},
    {sipName_ExtraButton11, static_cast<int>( ::Qt::ExtraButton11), 413},
    {sipName_ExtraButton12, static_cast<int>( ::Qt::ExtraButton12), 413},
    {sipName_ExtraButton13, static_cast<int>( ::Qt::ExtraButton13), 413},
    {sipName_ExtraButton14, static_cast<int>( ::Qt::ExtraButton14), 413},
    {sipName_ExtraButton15, static_cast<int>( ::Qt::ExtraButton15), 413},
    {sipName_ExtraButton16, static_cast<int>( ::Qt::ExtraButton16), 413},
    {sipName_ExtraButton17, static_cast<int>( ::Qt::ExtraButton17), 413},
    {sipName_ExtraButton18, static_cast<int>( ::Qt::ExtraButton18), 413},
    {sipName_ExtraButton19, static_cast<int>( ::Qt::ExtraButton19), 413},
    {sipName_ExtraButton2, static_cast<int>( ::Qt::ExtraButton2), 413},
    {sipName_ExtraButton20, static_cast<int>( ::Qt::ExtraButton20), 413},
    {sipName_ExtraButton21, static_cast<int>( ::Qt::ExtraButton21), 413},
    {sipName_ExtraButton22, static_cast<int>( ::Qt::ExtraButton22), 413},
    {sipName_ExtraButton23, static_cast<int>( ::Qt::ExtraButton23), 413},
    {sipName_ExtraButton24, static_cast<int>( ::Qt::ExtraButton24), 413},
    {sipName_ExtraButton3, static_cast<int>( ::Qt::ExtraButton3), 413},
    {sipName_ExtraButton4, static_cast<int>( ::Qt::ExtraButton4), 413},
    {sipName_ExtraButton5, static_cast<int>( ::Qt::ExtraButton5), 413},
    {sipName_ExtraButton6, static_cast<int>( ::Qt::ExtraButton6), 413},
    {sipName_ExtraButton7, static_cast<int>( ::Qt::ExtraButton7), 413},
    {sipName_ExtraButton8, static_cast<int>( ::Qt::ExtraButton8), 413},
    {sipName_ExtraButton9, static_cast<int>( ::Qt::ExtraButton9), 413},
    {sipName_FDiagPattern, static_cast<int>( ::Qt::FDiagPattern), 361},
    {sipName_FastTransformation, static_cast<int>( ::Qt::FastTransformation), 447},
    {sipName_FindChildrenRecursively, static_cast<int>( ::Qt::FindChildrenRecursively), 383},
    {sipName_FindDirectChildrenOnly, static_cast<int>( ::Qt::FindDirectChildrenOnly), 383},
    {sipName_FlatCap, static_cast<int>( ::Qt::FlatCap), 422},
    {sipName_Floor, static_cast<int>(::Qt::HighDpiScaleFactorRoundingPolicy::Floor), 392},
    {sipName_FontRole, static_cast<int>( ::Qt::FontRole), 400},
    {sipName_ForbiddenCursor, static_cast<int>( ::Qt::ForbiddenCursor), 371},
    {sipName_ForegroundRole, static_cast<int>( ::Qt::ForegroundRole), 400},
    {sipName_ForeignWindow, static_cast<int>( ::Qt::ForeignWindow), 456},
    {sipName_ForwardButton, static_cast<int>( ::Qt::ForwardButton), 413},
    {sipName_FramelessWindowHint, static_cast<int>( ::Qt::FramelessWindowHint), 456},
    {sipName_Friday, static_cast<int>( ::Qt::Friday), 373},
    {sipName_FuzzyHit, static_cast<int>( ::Qt::FuzzyHit), 393},
    {sipName_GestureCanceled, static_cast<int>( ::Qt::GestureCanceled), 389},
    {sipName_GestureFinished, static_cast<int>( ::Qt::GestureFinished), 389},
    {sipName_GestureStarted, static_cast<int>( ::Qt::GestureStarted), 389},
    {sipName_GestureUpdated, static_cast<int>( ::Qt::GestureUpdated), 389},
    {sipName_GroupSwitchModifier, static_cast<int>( ::Qt::GroupSwitchModifier), 406},
    {sipName_HighEventPriority, static_cast<int>( ::Qt::HighEventPriority), 381},
    {sipName_HorPattern, static_cast<int>( ::Qt::HorPattern), 361},
    {sipName_Horizontal, static_cast<int>( ::Qt::Horizontal), 420},
    {sipName_IBeamCursor, static_cast<int>( ::Qt::IBeamCursor), 371},
    {sipName_ISODate, static_cast<int>( ::Qt::ISODate), 372},
    {sipName_ISODateWithMs, static_cast<int>( ::Qt::ISODateWithMs), 372},
    {sipName_IgnoreAction, static_cast<int>( ::Qt::IgnoreAction), 376},
    {sipName_IgnoreAspectRatio, static_cast<int>( ::Qt::IgnoreAspectRatio), 358},
    {sipName_IgnoredGesturesPropagateToParent, static_cast<int>( ::Qt::IgnoredGesturesPropagateToParent), 387},
    {sipName_ImAbsolutePosition, static_cast<int>( ::Qt::ImAbsolutePosition), 399},
    {sipName_ImAnchorPosition, static_cast<int>( ::Qt::ImAnchorPosition), 399},
    {sipName_ImAnchorRectangle, static_cast<int>( ::Qt::ImAnchorRectangle), 399},
    {sipName_ImCurrentSelection, static_cast<int>( ::Qt::ImCurrentSelection), 399},
    {sipName_ImCursorPosition, static_cast<int>( ::Qt::ImCursorPosition), 399},
    {sipName_ImCursorRectangle, static_cast<int>( ::Qt::ImCursorRectangle), 399},
    {sipName_ImEnabled, static_cast<int>( ::Qt::ImEnabled), 399},
    {sipName_ImEnterKeyType, static_cast<int>( ::Qt::ImEnterKeyType), 399},
    {sipName_ImFont, static_cast<int>( ::Qt::ImFont), 399},
    {sipName_ImHints, static_cast<int>( ::Qt::ImHints), 399},
    {sipName_ImInputItemClipRectangle, static_cast<int>( ::Qt::ImInputItemClipRectangle), 399},
    {sipName_ImMaximumTextLength, static_cast<int>( ::Qt::ImMaximumTextLength), 399},
    {sipName_ImMicroFocus, static_cast<int>( ::Qt::ImMicroFocus), 399},
    {sipName_ImPlatformData, static_cast<int>( ::Qt::ImPlatformData), 399},
    {sipName_ImPreferredLanguage, static_cast<int>( ::Qt::ImPreferredLanguage), 399},
    {sipName_ImQueryAll, static_cast<int>( ::Qt::ImQueryAll), 399},
    {sipName_ImQueryInput, static_cast<int>( ::Qt::ImQueryInput), 399},
    {sipName_ImSurroundingText, static_cast<int>( ::Qt::ImSurroundingText), 399},
    {sipName_ImTextAfterCursor, static_cast<int>( ::Qt::ImTextAfterCursor), 399},
    {sipName_ImTextBeforeCursor, static_cast<int>( ::Qt::ImTextBeforeCursor), 399},
    {sipName_ImhDate, static_cast<int>( ::Qt::ImhDate), 396},
    {sipName_ImhDialableCharactersOnly, static_cast<int>( ::Qt::ImhDialableCharactersOnly), 396},
    {sipName_ImhDigitsOnly, static_cast<int>( ::Qt::ImhDigitsOnly), 396},
    {sipName_ImhEmailCharactersOnly, static_cast<int>( ::Qt::ImhEmailCharactersOnly), 396},
    {sipName_ImhExclusiveInputMask, static_cast<int>( ::Qt::ImhExclusiveInputMask), 396},
    {sipName_ImhFormattedNumbersOnly, static_cast<int>( ::Qt::ImhFormattedNumbersOnly), 396},
    {sipName_ImhHiddenText, static_cast<int>( ::Qt::ImhHiddenText), 396},
    {sipName_ImhLatinOnly, static_cast<int>( ::Qt::ImhLatinOnly), 396},
    {sipName_ImhLowercaseOnly, static_cast<int>( ::Qt::ImhLowercaseOnly), 396},
    {sipName_ImhMultiLine, static_cast<int>( ::Qt::ImhMultiLine), 396},
    {sipName_ImhNoAutoUppercase, static_cast<int>( ::Qt::ImhNoAutoUppercase), 396},
    {sipName_ImhNoEditMenu, static_cast<int>( ::Qt::ImhNoEditMenu), 396},
    {sipName_ImhNoPredictiveText, static_cast<int>( ::Qt::ImhNoPredictiveText), 396},
    {sipName_ImhNoTextHandles, static_cast<int>( ::Qt::ImhNoTextHandles), 396},
    {sipName_ImhNone, static_cast<int>( ::Qt::ImhNone), 396},
    {sipName_ImhPreferLatin, static_cast<int>( ::Qt::ImhPreferLatin), 396},
    {sipName_ImhPreferLowercase, static_cast<int>( ::Qt::ImhPreferLowercase), 396},
    {sipName_ImhPreferNumbers, static_cast<int>( ::Qt::ImhPreferNumbers), 396},
    {sipName_ImhPreferUppercase, static_cast<int>( ::Qt::ImhPreferUppercase), 396},
    {sipName_ImhSensitiveData, static_cast<int>( ::Qt::ImhSensitiveData), 396},
    {sipName_ImhTime, static_cast<int>( ::Qt::ImhTime), 396},
    {sipName_ImhUppercaseOnly, static_cast<int>( ::Qt::ImhUppercaseOnly), 396},
    {sipName_ImhUrlCharactersOnly, static_cast<int>( ::Qt::ImhUrlCharactersOnly), 396},
    {sipName_InitialSortOrderRole, static_cast<int>( ::Qt::InitialSortOrderRole), 400},
    {sipName_IntersectClip, static_cast<int>( ::Qt::IntersectClip), 365},
    {sipName_IntersectsItemBoundingRect, static_cast<int>( ::Qt::IntersectsItemBoundingRect), 403},
    {sipName_IntersectsItemShape, static_cast<int>( ::Qt::IntersectsItemShape), 403},
    {sipName_InvertedLandscapeOrientation, static_cast<int>( ::Qt::InvertedLandscapeOrientation), 425},
    {sipName_InvertedPortraitOrientation, static_cast<int>( ::Qt::InvertedPortraitOrientation), 425},
    {sipName_ItemIsAutoTristate, static_cast<int>( ::Qt::ItemIsAutoTristate), 401},
    {sipName_ItemIsDragEnabled, static_cast<int>( ::Qt::ItemIsDragEnabled), 401},
    {sipName_ItemIsDropEnabled, static_cast<int>( ::Qt::ItemIsDropEnabled), 401},
    {sipName_ItemIsEditable, static_cast<int>( ::Qt::ItemIsEditable), 401},
    {sipName_ItemIsEnabled, static_cast<int>( ::Qt::ItemIsEnabled), 401},
    {sipName_ItemIsSelectable, static_cast<int>( ::Qt::ItemIsSelectable), 401},
    {sipName_ItemIsTristate, static_cast<int>( ::Qt::ItemIsTristate), 401},
    {sipName_ItemIsUserCheckable, static_cast<int>( ::Qt::ItemIsUserCheckable), 401},
    {sipName_ItemIsUserTristate, static_cast<int>( ::Qt::ItemIsUserTristate), 401},
    {sipName_ItemNeverHasChildren, static_cast<int>( ::Qt::ItemNeverHasChildren), 401},
    {sipName_KeepAspectRatio, static_cast<int>( ::Qt::KeepAspectRatio), 358},
    {sipName_KeepAspectRatioByExpanding, static_cast<int>( ::Qt::KeepAspectRatioByExpanding), 358},
    {sipName_Key_0, static_cast<int>( ::Qt::Key_0), 405},
    {sipName_Key_1, static_cast<int>( ::Qt::Key_1), 405},
    {sipName_Key_2, static_cast<int>( ::Qt::Key_2), 405},
    {sipName_Key_3, static_cast<int>( ::Qt::Key_3), 405},
    {sipName_Key_4, static_cast<int>( ::Qt::Key_4), 405},
    {sipName_Key_5, static_cast<int>( ::Qt::Key_5), 405},
    {sipName_Key_6, static_cast<int>( ::Qt::Key_6), 405},
    {sipName_Key_7, static_cast<int>( ::Qt::Key_7), 405},
    {sipName_Key_8, static_cast<int>( ::Qt::Key_8), 405},
    {sipName_Key_9, static_cast<int>( ::Qt::Key_9), 405},
    {sipName_Key_A, static_cast<int>( ::Qt::Key_A), 405},
    {sipName_Key_AE, static_cast<int>( ::Qt::Key_AE), 405},
    {sipName_Key_Aacute, static_cast<int>( ::Qt::Key_Aacute), 405},
    {sipName_Key_Acircumflex, static_cast<int>( ::Qt::Key_Acircumflex), 405},
    {sipName_Key_AddFavorite, static_cast<int>( ::Qt::Key_AddFavorite), 405},
    {sipName_Key_Adiaeresis, static_cast<int>( ::Qt::Key_Adiaeresis), 405},
    {sipName_Key_Agrave, static_cast<int>( ::Qt::Key_Agrave), 405},
    {sipName_Key_Alt, static_cast<int>( ::Qt::Key_Alt), 405},
    {sipName_Key_AltGr, static_cast<int>( ::Qt::Key_AltGr), 405},
    {sipName_Key_Ampersand, static_cast<int>( ::Qt::Key_Ampersand), 405},
    {sipName_Key_Any, static_cast<int>( ::Qt::Key_Any), 405},
    {sipName_Key_Apostrophe, static_cast<int>( ::Qt::Key_Apostrophe), 405},
    {sipName_Key_ApplicationLeft, static_cast<int>( ::Qt::Key_ApplicationLeft), 405},
    {sipName_Key_ApplicationRight, static_cast<int>( ::Qt::Key_ApplicationRight), 405},
    {sipName_Key_Aring, static_cast<int>( ::Qt::Key_Aring), 405},
    {sipName_Key_AsciiCircum, static_cast<int>( ::Qt::Key_AsciiCircum), 405},
    {sipName_Key_AsciiTilde, static_cast<int>( ::Qt::Key_AsciiTilde), 405},
    {sipName_Key_Asterisk, static_cast<int>( ::Qt::Key_Asterisk), 405},
    {sipName_Key_At, static_cast<int>( ::Qt::Key_At), 405},
    {sipName_Key_Atilde, static_cast<int>( ::Qt::Key_Atilde), 405},
    {sipName_Key_AudioCycleTrack, static_cast<int>( ::Qt::Key_AudioCycleTrack), 405},
    {sipName_Key_AudioForward, static_cast<int>( ::Qt::Key_AudioForward), 405},
    {sipName_Key_AudioRandomPlay, static_cast<int>( ::Qt::Key_AudioRandomPlay), 405},
    {sipName_Key_AudioRepeat, static_cast<int>( ::Qt::Key_AudioRepeat), 405},
    {sipName_Key_AudioRewind, static_cast<int>( ::Qt::Key_AudioRewind), 405},
    {sipName_Key_Away, static_cast<int>( ::Qt::Key_Away), 405},
    {sipName_Key_B, static_cast<int>( ::Qt::Key_B), 405},
    {sipName_Key_Back, static_cast<int>( ::Qt::Key_Back), 405},
    {sipName_Key_BackForward, static_cast<int>( ::Qt::Key_BackForward), 405},
    {sipName_Key_Backslash, static_cast<int>( ::Qt::Key_Backslash), 405},
    {sipName_Key_Backspace, static_cast<int>( ::Qt::Key_Backspace), 405},
    {sipName_Key_Backtab, static_cast<int>( ::Qt::Key_Backtab), 405},
    {sipName_Key_Bar, static_cast<int>( ::Qt::Key_Bar), 405},
    {sipName_Key_BassBoost, static_cast<int>( ::Qt::Key_BassBoost), 405},
    {sipName_Key_BassDown, static_cast<int>( ::Qt::Key_BassDown), 405},
    {sipName_Key_BassUp, static_cast<int>( ::Qt::Key_BassUp), 405},
    {sipName_Key_Battery, static_cast<int>( ::Qt::Key_Battery), 405},
    {sipName_Key_Blue, static_cast<int>( ::Qt::Key_Blue), 405},
    {sipName_Key_Bluetooth, static_cast<int>( ::Qt::Key_Bluetooth), 405},
    {sipName_Key_Book, static_cast<int>( ::Qt::Key_Book), 405},
    {sipName_Key_BraceLeft, static_cast<int>( ::Qt::Key_BraceLeft), 405},
    {sipName_Key_BraceRight, static_cast<int>( ::Qt::Key_BraceRight), 405},
    {sipName_Key_BracketLeft, static_cast<int>( ::Qt::Key_BracketLeft), 405},
    {sipName_Key_BracketRight, static_cast<int>( ::Qt::Key_BracketRight), 405},
    {sipName_Key_BrightnessAdjust, static_cast<int>( ::Qt::Key_BrightnessAdjust), 405},
    {sipName_Key_C, static_cast<int>( ::Qt::Key_C), 405},
    {sipName_Key_CD, static_cast<int>( ::Qt::Key_CD), 405},
    {sipName_Key_Calculator, static_cast<int>( ::Qt::Key_Calculator), 405},
    {sipName_Key_Calendar, static_cast<int>( ::Qt::Key_Calendar), 405},
    {sipName_Key_Call, static_cast<int>( ::Qt::Key_Call), 405},
    {sipName_Key_Camera, static_cast<int>( ::Qt::Key_Camera), 405},
    {sipName_Key_CameraFocus, static_cast<int>( ::Qt::Key_CameraFocus), 405},
    {sipName_Key_Cancel, static_cast<int>( ::Qt::Key_Cancel), 405},
    {sipName_Key_CapsLock, static_cast<int>( ::Qt::Key_CapsLock), 405},
    {sipName_Key_Ccedilla, static_cast<int>( ::Qt::Key_Ccedilla), 405},
    {sipName_Key_ChannelDown, static_cast<int>( ::Qt::Key_ChannelDown), 405},
    {sipName_Key_ChannelUp, static_cast<int>( ::Qt::Key_ChannelUp), 405},
    {sipName_Key_Clear, static_cast<int>( ::Qt::Key_Clear), 405},
    {sipName_Key_ClearGrab, static_cast<int>( ::Qt::Key_ClearGrab), 405},
    {sipName_Key_Close, static_cast<int>( ::Qt::Key_Close), 405},
    {sipName_Key_Codeinput, static_cast<int>( ::Qt::Key_Codeinput), 405},
    {sipName_Key_Colon, static_cast<int>( ::Qt::Key_Colon), 405},
    {sipName_Key_Comma, static_cast<int>( ::Qt::Key_Comma), 405},
    {sipName_Key_Community, static_cast<int>( ::Qt::Key_Community), 405},
    {sipName_Key_Context1, static_cast<int>( ::Qt::Key_Context1), 405},
    {sipName_Key_Context2, static_cast<int>( ::Qt::Key_Context2), 405},
    {sipName_Key_Context3, static_cast<int>( ::Qt::Key_Context3), 405},
    {sipName_Key_Context4, static_cast<int>( ::Qt::Key_Context4), 405},
    {sipName_Key_ContrastAdjust, static_cast<int>( ::Qt::Key_ContrastAdjust), 405},
    {sipName_Key_Control, static_cast<int>( ::Qt::Key_Control), 405},
    {sipName_Key_Copy, static_cast<int>( ::Qt::Key_Copy), 405},
    {sipName_Key_Cut, static_cast<int>( ::Qt::Key_Cut), 405},
    {sipName_Key_D, static_cast<int>( ::Qt::Key_D), 405},
    {sipName_Key_DOS, static_cast<int>( ::Qt::Key_DOS), 405},
    {sipName_Key_Dead_A, static_cast<int>( ::Qt::Key_Dead_A), 405},
    {sipName_Key_Dead_Abovecomma, static_cast<int>( ::Qt::Key_Dead_Abovecomma), 405},
    {sipName_Key_Dead_Abovedot, static_cast<int>( ::Qt::Key_Dead_Abovedot), 405},
    {sipName_Key_Dead_Abovereversedcomma, static_cast<int>( ::Qt::Key_Dead_Abovereversedcomma), 405},
    {sipName_Key_Dead_Abovering, static_cast<int>( ::Qt::Key_Dead_Abovering), 405},
    {sipName_Key_Dead_Aboveverticalline, static_cast<int>( ::Qt::Key_Dead_Aboveverticalline), 405},
    {sipName_Key_Dead_Acute, static_cast<int>( ::Qt::Key_Dead_Acute), 405},
    {sipName_Key_Dead_Belowbreve, static_cast<int>( ::Qt::Key_Dead_Belowbreve), 405},
    {sipName_Key_Dead_Belowcircumflex, static_cast<int>( ::Qt::Key_Dead_Belowcircumflex), 405},
    {sipName_Key_Dead_Belowcomma, static_cast<int>( ::Qt::Key_Dead_Belowcomma), 405},
    {sipName_Key_Dead_Belowdiaeresis, static_cast<int>( ::Qt::Key_Dead_Belowdiaeresis), 405},
    {sipName_Key_Dead_Belowdot, static_cast<int>( ::Qt::Key_Dead_Belowdot), 405},
    {sipName_Key_Dead_Belowmacron, static_cast<int>( ::Qt::Key_Dead_Belowmacron), 405},
    {sipName_Key_Dead_Belowring, static_cast<int>( ::Qt::Key_Dead_Belowring), 405},
    {sipName_Key_Dead_Belowtilde, static_cast<int>( ::Qt::Key_Dead_Belowtilde), 405},
    {sipName_Key_Dead_Belowverticalline, static_cast<int>( ::Qt::Key_Dead_Belowverticalline), 405},
    {sipName_Key_Dead_Breve, static_cast<int>( ::Qt::Key_Dead_Breve), 405},
    {sipName_Key_Dead_Capital_Schwa, static_cast<int>( ::Qt::Key_Dead_Capital_Schwa), 405},
    {sipName_Key_Dead_Caron, static_cast<int>( ::Qt::Key_Dead_Caron), 405},
    {sipName_Key_Dead_Cedilla, static_cast<int>( ::Qt::Key_Dead_Cedilla), 405},
    {sipName_Key_Dead_Circumflex, static_cast<int>( ::Qt::Key_Dead_Circumflex), 405},
    {sipName_Key_Dead_Currency, static_cast<int>( ::Qt::Key_Dead_Currency), 405},
    {sipName_Key_Dead_Diaeresis, static_cast<int>( ::Qt::Key_Dead_Diaeresis), 405},
    {sipName_Key_Dead_Doubleacute, static_cast<int>( ::Qt::Key_Dead_Doubleacute), 405},
    {sipName_Key_Dead_Doublegrave, static_cast<int>( ::Qt::Key_Dead_Doublegrave), 405},
    {sipName_Key_Dead_E, static_cast<int>( ::Qt::Key_Dead_E), 405},
    {sipName_Key_Dead_Grave, static_cast<int>( ::Qt::Key_Dead_Grave), 405},
    {sipName_Key_Dead_Greek, static_cast<int>( ::Qt::Key_Dead_Greek), 405},
    {sipName_Key_Dead_Hook, static_cast<int>( ::Qt::Key_Dead_Hook), 405},
    {sipName_Key_Dead_Horn, static_cast<int>( ::Qt::Key_Dead_Horn), 405},
    {sipName_Key_Dead_I, static_cast<int>( ::Qt::Key_Dead_I), 405},
    {sipName_Key_Dead_Invertedbreve, static_cast<int>( ::Qt::Key_Dead_Invertedbreve), 405},
    {sipName_Key_Dead_Iota, static_cast<int>( ::Qt::Key_Dead_Iota), 405},
    {sipName_Key_Dead_Longsolidusoverlay, static_cast<int>( ::Qt::Key_Dead_Longsolidusoverlay), 405},
    {sipName_Key_Dead_Lowline, static_cast<int>( ::Qt::Key_Dead_Lowline), 405},
    {sipName_Key_Dead_Macron, static_cast<int>( ::Qt::Key_Dead_Macron), 405},
    {sipName_Key_Dead_O, static_cast<int>( ::Qt::Key_Dead_O), 405},
    {sipName_Key_Dead_Ogonek, static_cast<int>( ::Qt::Key_Dead_Ogonek), 405},
    {sipName_Key_Dead_Semivoiced_Sound, static_cast<int>( ::Qt::Key_Dead_Semivoiced_Sound), 405},
    {sipName_Key_Dead_Small_Schwa, static_cast<int>( ::Qt::Key_Dead_Small_Schwa), 405},
    {sipName_Key_Dead_Stroke, static_cast<int>( ::Qt::Key_Dead_Stroke), 405},
    {sipName_Key_Dead_Tilde, static_cast<int>( ::Qt::Key_Dead_Tilde), 405},
    {sipName_Key_Dead_U, static_cast<int>( ::Qt::Key_Dead_U), 405},
    {sipName_Key_Dead_Voiced_Sound, static_cast<int>( ::Qt::Key_Dead_Voiced_Sound), 405},
    {sipName_Key_Dead_a, static_cast<int>( ::Qt::Key_Dead_a), 405},
    {sipName_Key_Dead_e, static_cast<int>( ::Qt::Key_Dead_e), 405},
    {sipName_Key_Dead_i, static_cast<int>( ::Qt::Key_Dead_i), 405},
    {sipName_Key_Dead_o, static_cast<int>( ::Qt::Key_Dead_o), 405},
    {sipName_Key_Dead_u, static_cast<int>( ::Qt::Key_Dead_u), 405},
    {sipName_Key_Delete, static_cast<int>( ::Qt::Key_Delete), 405},
    {sipName_Key_Direction_L, static_cast<int>( ::Qt::Key_Direction_L), 405},
    {sipName_Key_Direction_R, static_cast<int>( ::Qt::Key_Direction_R), 405},
    {sipName_Key_Display, static_cast<int>( ::Qt::Key_Display), 405},
    {sipName_Key_Documents, static_cast<int>( ::Qt::Key_Documents), 405},
    {sipName_Key_Dollar, static_cast<int>( ::Qt::Key_Dollar), 405},
    {sipName_Key_Down, static_cast<int>( ::Qt::Key_Down), 405},
    {sipName_Key_E, static_cast<int>( ::Qt::Key_E), 405},
    {sipName_Key_ETH, static_cast<int>( ::Qt::Key_ETH), 405},
    {sipName_Key_Eacute, static_cast<int>( ::Qt::Key_Eacute), 405},
    {sipName_Key_Ecircumflex, static_cast<int>( ::Qt::Key_Ecircumflex), 405},
    {sipName_Key_Ediaeresis, static_cast<int>( ::Qt::Key_Ediaeresis), 405},
    {sipName_Key_Egrave, static_cast<int>( ::Qt::Key_Egrave), 405},
    {sipName_Key_Eisu_Shift, static_cast<int>( ::Qt::Key_Eisu_Shift), 405},
    {sipName_Key_Eisu_toggle, static_cast<int>( ::Qt::Key_Eisu_toggle), 405},
    {sipName_Key_Eject, static_cast<int>( ::Qt::Key_Eject), 405},
    {sipName_Key_End, static_cast<int>( ::Qt::Key_End), 405},
    {sipName_Key_Enter, static_cast<int>( ::Qt::Key_Enter), 405},
    {sipName_Key_Equal, static_cast<int>( ::Qt::Key_Equal), 405},
    {sipName_Key_Escape, static_cast<int>( ::Qt::Key_Escape), 405},
    {sipName_Key_Excel, static_cast<int>( ::Qt::Key_Excel), 405},
    {sipName_Key_Exclam, static_cast<int>( ::Qt::Key_Exclam), 405},
    {sipName_Key_Execute, static_cast<int>( ::Qt::Key_Execute), 405},
    {sipName_Key_Exit, static_cast<int>( ::Qt::Key_Exit), 405},
    {sipName_Key_Explorer, static_cast<int>( ::Qt::Key_Explorer), 405},
    {sipName_Key_F, static_cast<int>( ::Qt::Key_F), 405},
    {sipName_Key_F1, static_cast<int>( ::Qt::Key_F1), 405},
    {sipName_Key_F10, static_cast<int>( ::Qt::Key_F10), 405},
    {sipName_Key_F11, static_cast<int>( ::Qt::Key_F11), 405},
    {sipName_Key_F12, static_cast<int>( ::Qt::Key_F12), 405},
    {sipName_Key_F13, static_cast<int>( ::Qt::Key_F13), 405},
    {sipName_Key_F14, static_cast<int>( ::Qt::Key_F14), 405},
    {sipName_Key_F15, static_cast<int>( ::Qt::Key_F15), 405},
    {sipName_Key_F16, static_cast<int>( ::Qt::Key_F16), 405},
    {sipName_Key_F17, static_cast<int>( ::Qt::Key_F17), 405},
    {sipName_Key_F18, static_cast<int>( ::Qt::Key_F18), 405},
    {sipName_Key_F19, static_cast<int>( ::Qt::Key_F19), 405},
    {sipName_Key_F2, static_cast<int>( ::Qt::Key_F2), 405},
    {sipName_Key_F20, static_cast<int>( ::Qt::Key_F20), 405},
    {sipName_Key_F21, static_cast<int>( ::Qt::Key_F21), 405},
    {sipName_Key_F22, static_cast<int>( ::Qt::Key_F22), 405},
    {sipName_Key_F23, static_cast<int>( ::Qt::Key_F23), 405},
    {sipName_Key_F24, static_cast<int>( ::Qt::Key_F24), 405},
    {sipName_Key_F25, static_cast<int>( ::Qt::Key_F25), 405},
    {sipName_Key_F26, static_cast<int>( ::Qt::Key_F26), 405},
    {sipName_Key_F27, static_cast<int>( ::Qt::Key_F27), 405},
    {sipName_Key_F28, static_cast<int>( ::Qt::Key_F28), 405},
    {sipName_Key_F29, static_cast<int>( ::Qt::Key_F29), 405},
    {sipName_Key_F3, static_cast<int>( ::Qt::Key_F3), 405},
    {sipName_Key_F30, static_cast<int>( ::Qt::Key_F30), 405},
    {sipName_Key_F31, static_cast<int>( ::Qt::Key_F31), 405},
    {sipName_Key_F32, static_cast<int>( ::Qt::Key_F32), 405},
    {sipName_Key_F33, static_cast<int>( ::Qt::Key_F33), 405},
    {sipName_Key_F34, static_cast<int>( ::Qt::Key_F34), 405},
    {sipName_Key_F35, static_cast<int>( ::Qt::Key_F35), 405},
    {sipName_Key_F4, static_cast<int>( ::Qt::Key_F4), 405},
    {sipName_Key_F5, static_cast<int>( ::Qt::Key_F5), 405},
    {sipName_Key_F6, static_cast<int>( ::Qt::Key_F6), 405},
    {sipName_Key_F7, static_cast<int>( ::Qt::Key_F7), 405},
    {sipName_Key_F8, static_cast<int>( ::Qt::Key_F8), 405},
    {sipName_Key_F9, static_cast<int>( ::Qt::Key_F9), 405},
    {sipName_Key_Favorites, static_cast<int>( ::Qt::Key_Favorites), 405},
    {sipName_Key_Finance, static_cast<int>( ::Qt::Key_Finance), 405},
    {sipName_Key_Find, static_cast<int>( ::Qt::Key_Find), 405},
    {sipName_Key_Flip, static_cast<int>( ::Qt::Key_Flip), 405},
    {sipName_Key_Forward, static_cast<int>( ::Qt::Key_Forward), 405},
    {sipName_Key_G, static_cast<int>( ::Qt::Key_G), 405},
    {sipName_Key_Game, static_cast<int>( ::Qt::Key_Game), 405},
    {sipName_Key_Go, static_cast<int>( ::Qt::Key_Go), 405},
    {sipName_Key_Greater, static_cast<int>( ::Qt::Key_Greater), 405},
    {sipName_Key_Green, static_cast<int>( ::Qt::Key_Green), 405},
    {sipName_Key_Guide, static_cast<int>( ::Qt::Key_Guide), 405},
    {sipName_Key_H, static_cast<int>( ::Qt::Key_H), 405},
    {sipName_Key_Hangul, static_cast<int>( ::Qt::Key_Hangul), 405},
    {sipName_Key_Hangul_Banja, static_cast<int>( ::Qt::Key_Hangul_Banja), 405},
    {sipName_Key_Hangul_End, static_cast<int>( ::Qt::Key_Hangul_End), 405},
    {sipName_Key_Hangul_Hanja, static_cast<int>( ::Qt::Key_Hangul_Hanja), 405},
    {sipName_Key_Hangul_Jamo, static_cast<int>( ::Qt::Key_Hangul_Jamo), 405},
    {sipName_Key_Hangul_Jeonja, static_cast<int>( ::Qt::Key_Hangul_Jeonja), 405},
    {sipName_Key_Hangul_PostHanja, static_cast<int>( ::Qt::Key_Hangul_PostHanja), 405},
    {sipName_Key_Hangul_PreHanja, static_cast<int>( ::Qt::Key_Hangul_PreHanja), 405},
    {sipName_Key_Hangul_Romaja, static_cast<int>( ::Qt::Key_Hangul_Romaja), 405},
    {sipName_Key_Hangul_Special, static_cast<int>( ::Qt::Key_Hangul_Special), 405},
    {sipName_Key_Hangul_Start, static_cast<int>( ::Qt::Key_Hangul_Start), 405},
    {sipName_Key_Hangup, static_cast<int>( ::Qt::Key_Hangup), 405},
    {sipName_Key_Hankaku, static_cast<int>( ::Qt::Key_Hankaku), 405},
    {sipName_Key_Help, static_cast<int>( ::Qt::Key_Help), 405},
    {sipName_Key_Henkan, static_cast<int>( ::Qt::Key_Henkan), 405},
    {sipName_Key_Hibernate, static_cast<int>( ::Qt::Key_Hibernate), 405},
    {sipName_Key_Hiragana, static_cast<int>( ::Qt::Key_Hiragana), 405},
    {sipName_Key_Hiragana_Katakana, static_cast<int>( ::Qt::Key_Hiragana_Katakana), 405},
    {sipName_Key_History, static_cast<int>( ::Qt::Key_History), 405},
    {sipName_Key_Home, static_cast<int>( ::Qt::Key_Home), 405},
    {sipName_Key_HomePage, static_cast<int>( ::Qt::Key_HomePage), 405},
    {sipName_Key_HotLinks, static_cast<int>( ::Qt::Key_HotLinks), 405},
    {sipName_Key_Hyper_L, static_cast<int>( ::Qt::Key_Hyper_L), 405},
    {sipName_Key_Hyper_R, static_cast<int>( ::Qt::Key_Hyper_R), 405},
    {sipName_Key_I, static_cast<int>( ::Qt::Key_I), 405},
    {sipName_Key_Iacute, static_cast<int>( ::Qt::Key_Iacute), 405},
    {sipName_Key_Icircumflex, static_cast<int>( ::Qt::Key_Icircumflex), 405},
    {sipName_Key_Idiaeresis, static_cast<int>( ::Qt::Key_Idiaeresis), 405},
    {sipName_Key_Igrave, static_cast<int>( ::Qt::Key_Igrave), 405},
    {sipName_Key_Info, static_cast<int>( ::Qt::Key_Info), 405},
    {sipName_Key_Insert, static_cast<int>( ::Qt::Key_Insert), 405},
    {sipName_Key_J, static_cast<int>( ::Qt::Key_J), 405},
    {sipName_Key_K, static_cast<int>( ::Qt::Key_K), 405},
    {sipName_Key_Kana_Lock, static_cast<int>( ::Qt::Key_Kana_Lock), 405},
    {sipName_Key_Kana_Shift, static_cast<int>( ::Qt::Key_Kana_Shift), 405},
    {sipName_Key_Kanji, static_cast<int>( ::Qt::Key_Kanji), 405},
    {sipName_Key_Katakana, static_cast<int>( ::Qt::Key_Katakana), 405},
    {sipName_Key_KeyboardBrightnessDown, static_cast<int>( ::Qt::Key_KeyboardBrightnessDown), 405},
    {sipName_Key_KeyboardBrightnessUp, static_cast<int>( ::Qt::Key_KeyboardBrightnessUp), 405},
    {sipName_Key_KeyboardLightOnOff, static_cast<int>( ::Qt::Key_KeyboardLightOnOff), 405},
    {sipName_Key_L, static_cast<int>( ::Qt::Key_L), 405},
    {sipName_Key_LastNumberRedial, static_cast<int>( ::Qt::Key_LastNumberRedial), 405},
    {sipName_Key_Launch0, static_cast<int>( ::Qt::Key_Launch0), 405},
    {sipName_Key_Launch1, static_cast<int>( ::Qt::Key_Launch1), 405},
    {sipName_Key_Launch2, static_cast<int>( ::Qt::Key_Launch2), 405},
    {sipName_Key_Launch3, static_cast<int>( ::Qt::Key_Launch3), 405},
    {sipName_Key_Launch4, static_cast<int>( ::Qt::Key_Launch4), 405},
    {sipName_Key_Launch5, static_cast<int>( ::Qt::Key_Launch5), 405},
    {sipName_Key_Launch6, static_cast<int>( ::Qt::Key_Launch6), 405},
    {sipName_Key_Launch7, static_cast<int>( ::Qt::Key_Launch7), 405},
    {sipName_Key_Launch8, static_cast<int>( ::Qt::Key_Launch8), 405},
    {sipName_Key_Launch9, static_cast<int>( ::Qt::Key_Launch9), 405},
    {sipName_Key_LaunchA, static_cast<int>( ::Qt::Key_LaunchA), 405},
    {sipName_Key_LaunchB, static_cast<int>( ::Qt::Key_LaunchB), 405},
    {sipName_Key_LaunchC, static_cast<int>( ::Qt::Key_LaunchC), 405},
    {sipName_Key_LaunchD, static_cast<int>( ::Qt::Key_LaunchD), 405},
    {sipName_Key_LaunchE, static_cast<int>( ::Qt::Key_LaunchE), 405},
    {sipName_Key_LaunchF, static_cast<int>( ::Qt::Key_LaunchF), 405},
    {sipName_Key_LaunchG, static_cast<int>( ::Qt::Key_LaunchG), 405},
    {sipName_Key_LaunchH, static_cast<int>( ::Qt::Key_LaunchH), 405},
    {sipName_Key_LaunchMail, static_cast<int>( ::Qt::Key_LaunchMail), 405},
    {sipName_Key_LaunchMedia, static_cast<int>( ::Qt::Key_LaunchMedia), 405},
    {sipName_Key_Left, static_cast<int>( ::Qt::Key_Left), 405},
    {sipName_Key_Less, static_cast<int>( ::Qt::Key_Less), 405},
    {sipName_Key_LightBulb, static_cast<int>( ::Qt::Key_LightBulb), 405},
    {sipName_Key_LogOff, static_cast<int>( ::Qt::Key_LogOff), 405},
    {sipName_Key_M, static_cast<int>( ::Qt::Key_M), 405},
    {sipName_Key_MailForward, static_cast<int>( ::Qt::Key_MailForward), 405},
    {sipName_Key_Market, static_cast<int>( ::Qt::Key_Market), 405},
    {sipName_Key_Massyo, static_cast<int>( ::Qt::Key_Massyo), 405},
    {sipName_Key_MediaLast, static_cast<int>( ::Qt::Key_MediaLast), 405},
    {sipName_Key_MediaNext, static_cast<int>( ::Qt::Key_MediaNext), 405},
    {sipName_Key_MediaPause, static_cast<int>( ::Qt::Key_MediaPause), 405},
    {sipName_Key_MediaPlay, static_cast<int>( ::Qt::Key_MediaPlay), 405},
    {sipName_Key_MediaPrevious, static_cast<int>( ::Qt::Key_MediaPrevious), 405},
    {sipName_Key_MediaRecord, static_cast<int>( ::Qt::Key_MediaRecord), 405},
    {sipName_Key_MediaStop, static_cast<int>( ::Qt::Key_MediaStop), 405},
    {sipName_Key_MediaTogglePlayPause, static_cast<int>( ::Qt::Key_MediaTogglePlayPause), 405},
    {sipName_Key_Meeting, static_cast<int>( ::Qt::Key_Meeting), 405},
    {sipName_Key_Memo, static_cast<int>( ::Qt::Key_Memo), 405},
    {sipName_Key_Menu, static_cast<int>( ::Qt::Key_Menu), 405},
    {sipName_Key_MenuKB, static_cast<int>( ::Qt::Key_MenuKB), 405},
    {sipName_Key_MenuPB, static_cast<int>( ::Qt::Key_MenuPB), 405},
    {sipName_Key_Messenger, static_cast<int>( ::Qt::Key_Messenger), 405},
    {sipName_Key_Meta, static_cast<int>( ::Qt::Key_Meta), 405},
    {sipName_Key_MicMute, static_cast<int>( ::Qt::Key_MicMute), 405},
    {sipName_Key_MicVolumeDown, static_cast<int>( ::Qt::Key_MicVolumeDown), 405},
    {sipName_Key_MicVolumeUp, static_cast<int>( ::Qt::Key_MicVolumeUp), 405},
    {sipName_Key_Minus, static_cast<int>( ::Qt::Key_Minus), 405},
    {sipName_Key_Mode_switch, static_cast<int>( ::Qt::Key_Mode_switch), 405},
    {sipName_Key_MonBrightnessDown, static_cast<int>( ::Qt::Key_MonBrightnessDown), 405},
    {sipName_Key_MonBrightnessUp, static_cast<int>( ::Qt::Key_MonBrightnessUp), 405},
    {sipName_Key_Muhenkan, static_cast<int>( ::Qt::Key_Muhenkan), 405},
    {sipName_Key_Multi_key, static_cast<int>( ::Qt::Key_Multi_key), 405},
    {sipName_Key_MultipleCandidate, static_cast<int>( ::Qt::Key_MultipleCandidate), 405},
    {sipName_Key_Music, static_cast<int>( ::Qt::Key_Music), 405},
    {sipName_Key_MySites, static_cast<int>( ::Qt::Key_MySites), 405},
    {sipName_Key_N, static_cast<int>( ::Qt::Key_N), 405},
    {sipName_Key_New, static_cast<int>( ::Qt::Key_New), 405},
    {sipName_Key_News, static_cast<int>( ::Qt::Key_News), 405},
    {sipName_Key_No, static_cast<int>( ::Qt::Key_No), 405},
    {sipName_Key_Ntilde, static_cast<int>( ::Qt::Key_Ntilde), 405},
    {sipName_Key_NumLock, static_cast<int>( ::Qt::Key_NumLock), 405},
    {sipName_Key_NumberSign, static_cast<int>( ::Qt::Key_NumberSign), 405},
    {sipName_Key_O, static_cast<int>( ::Qt::Key_O), 405},
    {sipName_Key_Oacute, static_cast<int>( ::Qt::Key_Oacute), 405},
    {sipName_Key_Ocircumflex, static_cast<int>( ::Qt::Key_Ocircumflex), 405},
    {sipName_Key_Odiaeresis, static_cast<int>( ::Qt::Key_Odiaeresis), 405},
    {sipName_Key_OfficeHome, static_cast<int>( ::Qt::Key_OfficeHome), 405},
    {sipName_Key_Ograve, static_cast<int>( ::Qt::Key_Ograve), 405},
    {sipName_Key_Ooblique, static_cast<int>( ::Qt::Key_Ooblique), 405},
    {sipName_Key_Open, static_cast<int>( ::Qt::Key_Open), 405},
    {sipName_Key_OpenUrl, static_cast<int>( ::Qt::Key_OpenUrl), 405},
    {sipName_Key_Option, static_cast<int>( ::Qt::Key_Option), 405},
    {sipName_Key_Otilde, static_cast<int>( ::Qt::Key_Otilde), 405},
    {sipName_Key_P, static_cast<int>( ::Qt::Key_P), 405},
    {sipName_Key_PageDown, static_cast<int>( ::Qt::Key_PageDown), 405},
    {sipName_Key_PageUp, static_cast<int>( ::Qt::Key_PageUp), 405},
    {sipName_Key_ParenLeft, static_cast<int>( ::Qt::Key_ParenLeft), 405},
    {sipName_Key_ParenRight, static_cast<int>( ::Qt::Key_ParenRight), 405},
    {sipName_Key_Paste, static_cast<int>( ::Qt::Key_Paste), 405},
    {sipName_Key_Pause, static_cast<int>( ::Qt::Key_Pause), 405},
    {sipName_Key_Percent, static_cast<int>( ::Qt::Key_Percent), 405},
    {sipName_Key_Period, static_cast<int>( ::Qt::Key_Period), 405},
    {sipName_Key_Phone, static_cast<int>( ::Qt::Key_Phone), 405},
    {sipName_Key_Pictures, static_cast<int>( ::Qt::Key_Pictures), 405},
    {sipName_Key_Play, static_cast<int>( ::Qt::Key_Play), 405},
    {sipName_Key_Plus, static_cast<int>( ::Qt::Key_Plus), 405},
    {sipName_Key_PowerDown, static_cast<int>( ::Qt::Key_PowerDown), 405},
    {sipName_Key_PowerOff, static_cast<int>( ::Qt::Key_PowerOff), 405},
    {sipName_Key_PreviousCandidate, static_cast<int>( ::Qt::Key_PreviousCandidate), 405},
    {sipName_Key_Print, static_cast<int>( ::Qt::Key_Print), 405},
    {sipName_Key_Printer, static_cast<int>( ::Qt::Key_Printer), 405},
    {sipName_Key_Q, static_cast<int>( ::Qt::Key_Q), 405},
    {sipName_Key_Question, static_cast<int>( ::Qt::Key_Question), 405},
    {sipName_Key_QuoteDbl, static_cast<int>( ::Qt::Key_QuoteDbl), 405},
    {sipName_Key_QuoteLeft, static_cast<int>( ::Qt::Key_QuoteLeft), 405},
    {sipName_Key_R, static_cast<int>( ::Qt::Key_R), 405},
    {sipName_Key_Red, static_cast<int>( ::Qt::Key_Red), 405},
    {sipName_Key_Redo, static_cast<int>( ::Qt::Key_Redo), 405},
    {sipName_Key_Refresh, static_cast<int>( ::Qt::Key_Refresh), 405},
    {sipName_Key_Reload, static_cast<int>( ::Qt::Key_Reload), 405},
    {sipName_Key_Reply, static_cast<int>( ::Qt::Key_Reply), 405},
    {sipName_Key_Return, static_cast<int>( ::Qt::Key_Return), 405},
    {sipName_Key_Right, static_cast<int>( ::Qt::Key_Right), 405},
    {sipName_Key_Romaji, static_cast<int>( ::Qt::Key_Romaji), 405},
    {sipName_Key_RotateWindows, static_cast<int>( ::Qt::Key_RotateWindows), 405},
    {sipName_Key_RotationKB, static_cast<int>( ::Qt::Key_RotationKB), 405},
    {sipName_Key_RotationPB, static_cast<int>( ::Qt::Key_RotationPB), 405},
    {sipName_Key_S, static_cast<int>( ::Qt::Key_S), 405},
    {sipName_Key_Save, static_cast<int>( ::Qt::Key_Save), 405},
    {sipName_Key_ScreenSaver, static_cast<int>( ::Qt::Key_ScreenSaver), 405},
    {sipName_Key_ScrollLock, static_cast<int>( ::Qt::Key_ScrollLock), 405},
    {sipName_Key_Search, static_cast<int>( ::Qt::Key_Search), 405},
    {sipName_Key_Select, static_cast<int>( ::Qt::Key_Select), 405},
    {sipName_Key_Semicolon, static_cast<int>( ::Qt::Key_Semicolon), 405},
    {sipName_Key_Send, static_cast<int>( ::Qt::Key_Send), 405},
    {sipName_Key_Settings, static_cast<int>( ::Qt::Key_Settings), 405},
    {sipName_Key_Shift, static_cast<int>( ::Qt::Key_Shift), 405},
    {sipName_Key_Shop, static_cast<int>( ::Qt::Key_Shop), 405},
    {sipName_Key_SingleCandidate, static_cast<int>( ::Qt::Key_SingleCandidate), 405},
    {sipName_Key_Slash, static_cast<int>( ::Qt::Key_Slash), 405},
    {sipName_Key_Sleep, static_cast<int>( ::Qt::Key_Sleep), 405},
    {sipName_Key_Space, static_cast<int>( ::Qt::Key_Space), 405},
    {sipName_Key_Spell, static_cast<int>( ::Qt::Key_Spell), 405},
    {sipName_Key_SplitScreen, static_cast<int>( ::Qt::Key_SplitScreen), 405},
    {sipName_Key_Standby, static_cast<int>( ::Qt::Key_Standby), 405},
    {sipName_Key_Stop, static_cast<int>( ::Qt::Key_Stop), 405},
    {sipName_Key_Subtitle, static_cast<int>( ::Qt::Key_Subtitle), 405},
    {sipName_Key_Super_L, static_cast<int>( ::Qt::Key_Super_L), 405},
    {sipName_Key_Super_R, static_cast<int>( ::Qt::Key_Super_R), 405},
    {sipName_Key_Support, static_cast<int>( ::Qt::Key_Support), 405},
    {sipName_Key_Suspend, static_cast<int>( ::Qt::Key_Suspend), 405},
    {sipName_Key_SysReq, static_cast<int>( ::Qt::Key_SysReq), 405},
    {sipName_Key_T, static_cast<int>( ::Qt::Key_T), 405},
    {sipName_Key_THORN, static_cast<int>( ::Qt::Key_THORN), 405},
    {sipName_Key_Tab, static_cast<int>( ::Qt::Key_Tab), 405},
    {sipName_Key_TaskPane, static_cast<int>( ::Qt::Key_TaskPane), 405},
    {sipName_Key_Terminal, static_cast<int>( ::Qt::Key_Terminal), 405},
    {sipName_Key_Time, static_cast<int>( ::Qt::Key_Time), 405},
    {sipName_Key_ToDoList, static_cast<int>( ::Qt::Key_ToDoList), 405},
    {sipName_Key_ToggleCallHangup, static_cast<int>( ::Qt::Key_ToggleCallHangup), 405},
    {sipName_Key_Tools, static_cast<int>( ::Qt::Key_Tools), 405},
    {sipName_Key_TopMenu, static_cast<int>( ::Qt::Key_TopMenu), 405},
    {sipName_Key_TouchpadOff, static_cast<int>( ::Qt::Key_TouchpadOff), 405},
    {sipName_Key_TouchpadOn, static_cast<int>( ::Qt::Key_TouchpadOn), 405},
    {sipName_Key_TouchpadToggle, static_cast<int>( ::Qt::Key_TouchpadToggle), 405},
    {sipName_Key_Touroku, static_cast<int>( ::Qt::Key_Touroku), 405},
    {sipName_Key_Travel, static_cast<int>( ::Qt::Key_Travel), 405},
    {sipName_Key_TrebleDown, static_cast<int>( ::Qt::Key_TrebleDown), 405},
    {sipName_Key_TrebleUp, static_cast<int>( ::Qt::Key_TrebleUp), 405},
    {sipName_Key_U, static_cast<int>( ::Qt::Key_U), 405},
    {sipName_Key_UWB, static_cast<int>( ::Qt::Key_UWB), 405},
    {sipName_Key_Uacute, static_cast<int>( ::Qt::Key_Uacute), 405},
    {sipName_Key_Ucircumflex, static_cast<int>( ::Qt::Key_Ucircumflex), 405},
    {sipName_Key_Udiaeresis, static_cast<int>( ::Qt::Key_Udiaeresis), 405},
    {sipName_Key_Ugrave, static_cast<int>( ::Qt::Key_Ugrave), 405},
    {sipName_Key_Underscore, static_cast<int>( ::Qt::Key_Underscore), 405},
    {sipName_Key_Undo, static_cast<int>( ::Qt::Key_Undo), 405},
    {sipName_Key_Up, static_cast<int>( ::Qt::Key_Up), 405},
    {sipName_Key_V, static_cast<int>( ::Qt::Key_V), 405},
    {sipName_Key_Video, static_cast<int>( ::Qt::Key_Video), 405},
    {sipName_Key_View, static_cast<int>( ::Qt::Key_View), 405},
    {sipName_Key_VoiceDial, static_cast<int>( ::Qt::Key_VoiceDial), 405},
    {sipName_Key_VolumeDown, static_cast<int>( ::Qt::Key_VolumeDown), 405},
    {sipName_Key_VolumeMute, static_cast<int>( ::Qt::Key_VolumeMute), 405},
    {sipName_Key_VolumeUp, static_cast<int>( ::Qt::Key_VolumeUp), 405},
    {sipName_Key_W, static_cast<int>( ::Qt::Key_W), 405},
    {sipName_Key_WLAN, static_cast<int>( ::Qt::Key_WLAN), 405},
    {sipName_Key_WWW, static_cast<int>( ::Qt::Key_WWW), 405},
    {sipName_Key_WakeUp, static_cast<int>( ::Qt::Key_WakeUp), 405},
    {sipName_Key_WebCam, static_cast<int>( ::Qt::Key_WebCam), 405},
    {sipName_Key_Word, static_cast<int>( ::Qt::Key_Word), 405},
    {sipName_Key_X, static_cast<int>( ::Qt::Key_X), 405},
    {sipName_Key_Xfer, static_cast<int>( ::Qt::Key_Xfer), 405},
    {sipName_Key_Y, static_cast<int>( ::Qt::Key_Y), 405},
    {sipName_Key_Yacute, static_cast<int>( ::Qt::Key_Yacute), 405},
    {sipName_Key_Yellow, static_cast<int>( ::Qt::Key_Yellow), 405},
    {sipName_Key_Yes, static_cast<int>( ::Qt::Key_Yes), 405},
    {sipName_Key_Z, static_cast<int>( ::Qt::Key_Z), 405},
    {sipName_Key_Zenkaku, static_cast<int>( ::Qt::Key_Zenkaku), 405},
    {sipName_Key_Zenkaku_Hankaku, static_cast<int>( ::Qt::Key_Zenkaku_Hankaku), 405},
    {sipName_Key_Zoom, static_cast<int>( ::Qt::Key_Zoom), 405},
    {sipName_Key_ZoomIn, static_cast<int>( ::Qt::Key_ZoomIn), 405},
    {sipName_Key_ZoomOut, static_cast<int>( ::Qt::Key_ZoomOut), 405},
    {sipName_Key_acute, static_cast<int>( ::Qt::Key_acute), 405},
    {sipName_Key_brokenbar, static_cast<int>( ::Qt::Key_brokenbar), 405},
    {sipName_Key_cedilla, static_cast<int>( ::Qt::Key_cedilla), 405},
    {sipName_Key_cent, static_cast<int>( ::Qt::Key_cent), 405},
    {sipName_Key_copyright, static_cast<int>( ::Qt::Key_copyright), 405},
    {sipName_Key_currency, static_cast<int>( ::Qt::Key_currency), 405},
    {sipName_Key_degree, static_cast<int>( ::Qt::Key_degree), 405},
    {sipName_Key_diaeresis, static_cast<int>( ::Qt::Key_diaeresis), 405},
    {sipName_Key_division, static_cast<int>( ::Qt::Key_division), 405},
    {sipName_Key_exclamdown, static_cast<int>( ::Qt::Key_exclamdown), 405},
    {sipName_Key_guillemotleft, static_cast<int>( ::Qt::Key_guillemotleft), 405},
    {sipName_Key_guillemotright, static_cast<int>( ::Qt::Key_guillemotright), 405},
    {sipName_Key_hyphen, static_cast<int>( ::Qt::Key_hyphen), 405},
    {sipName_Key_iTouch, static_cast<int>( ::Qt::Key_iTouch), 405},
    {sipName_Key_macron, static_cast<int>( ::Qt::Key_macron), 405},
    {sipName_Key_masculine, static_cast<int>( ::Qt::Key_masculine), 405},
    {sipName_Key_mu, static_cast<int>( ::Qt::Key_mu), 405},
    {sipName_Key_multiply, static_cast<int>( ::Qt::Key_multiply), 405},
    {sipName_Key_nobreakspace, static_cast<int>( ::Qt::Key_nobreakspace), 405},
    {sipName_Key_notsign, static_cast<int>( ::Qt::Key_notsign), 405},
    {sipName_Key_onehalf, static_cast<int>( ::Qt::Key_onehalf), 405},
    {sipName_Key_onequarter, static_cast<int>( ::Qt::Key_onequarter), 405},
    {sipName_Key_onesuperior, static_cast<int>( ::Qt::Key_onesuperior), 405},
    {sipName_Key_ordfeminine, static_cast<int>( ::Qt::Key_ordfeminine), 405},
    {sipName_Key_paragraph, static_cast<int>( ::Qt::Key_paragraph), 405},
    {sipName_Key_periodcentered, static_cast<int>( ::Qt::Key_periodcentered), 405},
    {sipName_Key_plusminus, static_cast<int>( ::Qt::Key_plusminus), 405},
    {sipName_Key_questiondown, static_cast<int>( ::Qt::Key_questiondown), 405},
    {sipName_Key_registered, static_cast<int>( ::Qt::Key_registered), 405},
    {sipName_Key_section, static_cast<int>( ::Qt::Key_section), 405},
    {sipName_Key_ssharp, static_cast<int>( ::Qt::Key_ssharp), 405},
    {sipName_Key_sterling, static_cast<int>( ::Qt::Key_sterling), 405},
    {sipName_Key_threequarters, static_cast<int>( ::Qt::Key_threequarters), 405},
    {sipName_Key_threesuperior, static_cast<int>( ::Qt::Key_threesuperior), 405},
    {sipName_Key_twosuperior, static_cast<int>( ::Qt::Key_twosuperior), 405},
    {sipName_Key_unknown, static_cast<int>( ::Qt::Key_unknown), 405},
    {sipName_Key_ydiaeresis, static_cast<int>( ::Qt::Key_ydiaeresis), 405},
    {sipName_Key_yen, static_cast<int>( ::Qt::Key_yen), 405},
    {sipName_KeyboardModifierMask, static_cast<int>( ::Qt::KeyboardModifierMask), 406},
    {sipName_KeypadModifier, static_cast<int>( ::Qt::KeypadModifier), 406},
    {sipName_LandscapeOrientation, static_cast<int>( ::Qt::LandscapeOrientation), 425},
    {sipName_LastCursor, static_cast<int>( ::Qt::LastCursor), 371},
    {sipName_LayoutDirectionAuto, static_cast<int>( ::Qt::LayoutDirectionAuto), 408},
    {sipName_LeftArrow, static_cast<int>( ::Qt::LeftArrow), 357},
    {sipName_LeftButton, static_cast<int>( ::Qt::LeftButton), 413},
    {sipName_LeftDockWidgetArea, static_cast<int>( ::Qt::LeftDockWidgetArea), 374},
    {sipName_LeftEdge, static_cast<int>( ::Qt::LeftEdge), 378},
    {sipName_LeftSection, static_cast<int>( ::Qt::LeftSection), 452},
    {sipName_LeftToRight, static_cast<int>( ::Qt::LeftToRight), 408},
    {sipName_LeftToolBarArea, static_cast<int>( ::Qt::LeftToolBarArea), 442},
    {sipName_LinearGradientPattern, static_cast<int>( ::Qt::LinearGradientPattern), 361},
    {sipName_LinkAction, static_cast<int>( ::Qt::LinkAction), 376},
    {sipName_LinksAccessibleByKeyboard, static_cast<int>( ::Qt::LinksAccessibleByKeyboard), 437},
    {sipName_LinksAccessibleByMouse, static_cast<int>( ::Qt::LinksAccessibleByMouse), 437},
    {sipName_LocalDate, static_cast<int>( ::Qt::LocalDate), 372},
    {sipName_LocalTime, static_cast<int>( ::Qt::LocalTime), 440},
    {sipName_LocaleDate, static_cast<int>( ::Qt::LocaleDate), 372},
    {sipName_LogicalCoordinates, static_cast<int>( ::Qt::LogicalCoordinates), 368},
    {sipName_LogicalMoveStyle, static_cast<int>( ::Qt::LogicalMoveStyle), 370},
    {sipName_LowEventPriority, static_cast<int>( ::Qt::LowEventPriority), 381},
    {sipName_META, static_cast<int>( ::Qt::META), 412},
    {sipName_MODIFIER_MASK, static_cast<int>( ::Qt::MODIFIER_MASK), 412},
    {sipName_MPenCapStyle, static_cast<int>( ::Qt::MPenCapStyle), 422},
    {sipName_MPenJoinStyle, static_cast<int>( ::Qt::MPenJoinStyle), 423},
    {sipName_MPenStyle, static_cast<int>( ::Qt::MPenStyle), 424},
    {sipName_MSWindowsFixedSizeDialogHint, static_cast<int>( ::Qt::MSWindowsFixedSizeDialogHint), 456},
    {sipName_MSWindowsOwnDC, static_cast<int>( ::Qt::MSWindowsOwnDC), 456},
    {sipName_MacWindowToolBarButtonHint, static_cast<int>( ::Qt::MacWindowToolBarButtonHint), 456},
    {sipName_MarkdownText, static_cast<int>( ::Qt::MarkdownText), 436},
    {sipName_MaskInColor, static_cast<int>( ::Qt::MaskInColor), 409},
    {sipName_MaskOutColor, static_cast<int>( ::Qt::MaskOutColor), 409},
    {sipName_MatchCaseSensitive, static_cast<int>( ::Qt::MatchCaseSensitive), 410},
    {sipName_MatchContains, static_cast<int>( ::Qt::MatchContains), 410},
    {sipName_MatchEndsWith, static_cast<int>( ::Qt::MatchEndsWith), 410},
    {sipName_MatchExactly, static_cast<int>( ::Qt::MatchExactly), 410},
    {sipName_MatchFixedString, static_cast<int>( ::Qt::MatchFixedString), 410},
    {sipName_MatchRecursive, static_cast<int>( ::Qt::MatchRecursive), 410},
    {sipName_MatchRegExp, static_cast<int>( ::Qt::MatchRegExp), 410},
    {sipName_MatchRegularExpression, static_cast<int>( ::Qt::MatchRegularExpression), 410},
    {sipName_MatchStartsWith, static_cast<int>( ::Qt::MatchStartsWith), 410},
    {sipName_MatchWildcard, static_cast<int>( ::Qt::MatchWildcard), 410},
    {sipName_MatchWrap, static_cast<int>( ::Qt::MatchWrap), 410},
    {sipName_MaximizeUsingFullscreenGeometryHint, static_cast<int>( ::Qt::MaximizeUsingFullscreenGeometryHint), 456},
    {sipName_MaximumSize, static_cast<int>( ::Qt::MaximumSize), 430},
    {sipName_MenuBarFocusReason, static_cast<int>( ::Qt::MenuBarFocusReason), 386},
    {sipName_MetaModifier, static_cast<int>( ::Qt::MetaModifier), 406},
    {sipName_MidButton, static_cast<int>( ::Qt::MidButton), 413},
    {sipName_MiddleButton, static_cast<int>( ::Qt::MiddleButton), 413},
    {sipName_MinimumDescent, static_cast<int>( ::Qt::MinimumDescent), 430},
    {sipName_MinimumSize, static_cast<int>( ::Qt::MinimumSize), 430},
    {sipName_MiterJoin, static_cast<int>( ::Qt::MiterJoin), 423},
    {sipName_Monday, static_cast<int>( ::Qt::Monday), 373},
    {sipName_MonoOnly, static_cast<int>( ::Qt::MonoOnly), 394},
    {sipName_MouseEventCreatedDoubleClick, static_cast<int>( ::Qt::MouseEventCreatedDoubleClick), 415},
    {sipName_MouseEventNotSynthesized, static_cast<int>( ::Qt::MouseEventNotSynthesized), 417},
    {sipName_MouseEventSynthesizedByApplication, static_cast<int>( ::Qt::MouseEventSynthesizedByApplication), 417},
    {sipName_MouseEventSynthesizedByQt, static_cast<int>( ::Qt::MouseEventSynthesizedByQt), 417},
    {sipName_MouseEventSynthesizedBySystem, static_cast<int>( ::Qt::MouseEventSynthesizedBySystem), 417},
    {sipName_MouseFocusReason, static_cast<int>( ::Qt::MouseFocusReason), 386},
    {sipName_MoveAction, static_cast<int>( ::Qt::MoveAction), 376},
    {sipName_NavigationModeCursorAuto, static_cast<int>( ::Qt::NavigationModeCursorAuto), 419},
    {sipName_NavigationModeCursorForceVisible, static_cast<int>( ::Qt::NavigationModeCursorForceVisible), 419},
    {sipName_NavigationModeKeypadDirectional, static_cast<int>( ::Qt::NavigationModeKeypadDirectional), 419},
    {sipName_NavigationModeKeypadTabOrder, static_cast<int>( ::Qt::NavigationModeKeypadTabOrder), 419},
    {sipName_NavigationModeNone, static_cast<int>( ::Qt::NavigationModeNone), 419},
    {sipName_NoArrow, static_cast<int>( ::Qt::NoArrow), 357},
    {sipName_NoBrush, static_cast<int>( ::Qt::NoBrush), 361},
    {sipName_NoButton, static_cast<int>( ::Qt::NoButton), 413},
    {sipName_NoClip, static_cast<int>( ::Qt::NoClip), 365},
    {sipName_NoContextMenu, static_cast<int>( ::Qt::NoContextMenu), 367},
    {sipName_NoDockWidgetArea, static_cast<int>( ::Qt::NoDockWidgetArea), 374},
    {sipName_NoDropShadowWindowHint, static_cast<int>( ::Qt::NoDropShadowWindowHint), 456},
    {sipName_NoFocus, static_cast<int>( ::Qt::NoFocus), 385},
    {sipName_NoFocusReason, static_cast<int>( ::Qt::NoFocusReason), 386},
    {sipName_NoFormatConversion, static_cast<int>( ::Qt::NoFormatConversion), 394},
    {sipName_NoItemFlags, static_cast<int>( ::Qt::NoItemFlags), 401},
    {sipName_NoModifier, static_cast<int>( ::Qt::NoModifier), 406},
    {sipName_NoOpaqueDetection, static_cast<int>( ::Qt::NoOpaqueDetection), 394},
    {sipName_NoPen, static_cast<int>( ::Qt::NoPen), 424},
    {sipName_NoScrollPhase, static_cast<int>( ::Qt::NoScrollPhase), 428},
    {sipName_NoSection, static_cast<int>( ::Qt::NoSection), 452},
    {sipName_NoTabFocus, static_cast<int>( ::Qt::NoTabFocus), 433},
    {sipName_NoTextInteraction, static_cast<int>( ::Qt::NoTextInteraction), 437},
    {sipName_NoToolBarArea, static_cast<int>( ::Qt::NoToolBarArea), 442},
    {sipName_NonModal, static_cast<int>( ::Qt::NonModal), 453},
    {sipName_NormalEventPriority, static_cast<int>( ::Qt::NormalEventPriority), 381},
    {sipName_OddEvenFill, static_cast<int>( ::Qt::OddEvenFill), 382},
    {sipName_OffsetFromUTC, static_cast<int>( ::Qt::OffsetFromUTC), 440},
    {sipName_OpaqueMode, static_cast<int>( ::Qt::OpaqueMode), 360},
    {sipName_OpenHandCursor, static_cast<int>( ::Qt::OpenHandCursor), 371},
    {sipName_OrderedAlphaDither, static_cast<int>( ::Qt::OrderedAlphaDither), 394},
    {sipName_OrderedDither, static_cast<int>( ::Qt::OrderedDither), 394},
    {sipName_OtherFocusReason, static_cast<int>( ::Qt::OtherFocusReason), 386},
    {sipName_PanGesture, static_cast<int>( ::Qt::PanGesture), 390},
    {sipName_PanNativeGesture, static_cast<int>( ::Qt::PanNativeGesture), 418},
    {sipName_PartiallyChecked, static_cast<int>( ::Qt::PartiallyChecked), 363},
    {sipName_PassThrough, static_cast<int>(::Qt::HighDpiScaleFactorRoundingPolicy::PassThrough), 392},
    {sipName_PinchGesture, static_cast<int>( ::Qt::PinchGesture), 390},
    {sipName_PlainText, static_cast<int>( ::Qt::PlainText), 436},
    {sipName_PointingHandCursor, static_cast<int>( ::Qt::PointingHandCursor), 371},
    {sipName_Popup, static_cast<int>( ::Qt::Popup), 456},
    {sipName_PopupFocusReason, static_cast<int>( ::Qt::PopupFocusReason), 386},
    {sipName_PortraitOrientation, static_cast<int>( ::Qt::PortraitOrientation), 425},
    {sipName_PreciseTimer, static_cast<int>( ::Qt::PreciseTimer), 441},
    {sipName_PreferDither, static_cast<int>( ::Qt::PreferDither), 394},
    {sipName_PreferredSize, static_cast<int>( ::Qt::PreferredSize), 430},
    {sipName_PreventContextMenu, static_cast<int>( ::Qt::PreventContextMenu), 367},
    {sipName_PrimaryOrientation, static_cast<int>( ::Qt::PrimaryOrientation), 425},
    {sipName_QueuedConnection, static_cast<int>( ::Qt::QueuedConnection), 366},
    {sipName_RFC2822Date, static_cast<int>( ::Qt::RFC2822Date), 372},
    {sipName_RadialGradientPattern, static_cast<int>( ::Qt::RadialGradientPattern), 361},
    {sipName_ReceivePartialGestures, static_cast<int>( ::Qt::ReceivePartialGestures), 387},
    {sipName_RelativeSize, static_cast<int>( ::Qt::RelativeSize), 431},
    {sipName_RepeatTile, static_cast<int>( ::Qt::RepeatTile), 439},
    {sipName_ReplaceClip, static_cast<int>( ::Qt::ReplaceClip), 365},
    {sipName_ReplaceSelection, static_cast<int>( ::Qt::ReplaceSelection), 404},
    {sipName_RichText, static_cast<int>( ::Qt::RichText), 436},
    {sipName_RightArrow, static_cast<int>( ::Qt::RightArrow), 357},
    {sipName_RightButton, static_cast<int>( ::Qt::RightButton), 413},
    {sipName_RightDockWidgetArea, static_cast<int>( ::Qt::RightDockWidgetArea), 374},
    {sipName_RightEdge, static_cast<int>( ::Qt::RightEdge), 378},
    {sipName_RightSection, static_cast<int>( ::Qt::RightSection), 452},
    {sipName_RightToLeft, static_cast<int>( ::Qt::RightToLeft), 408},
    {sipName_RightToolBarArea, static_cast<int>( ::Qt::RightToolBarArea), 442},
    {sipName_RotateNativeGesture, static_cast<int>( ::Qt::RotateNativeGesture), 418},
    {sipName_Round, static_cast<int>(::Qt::HighDpiScaleFactorRoundingPolicy::Round), 392},
    {sipName_RoundCap, static_cast<int>( ::Qt::RoundCap), 422},
    {sipName_RoundJoin, static_cast<int>( ::Qt::RoundJoin), 423},
    {sipName_RoundPreferFloor, static_cast<int>(::Qt::HighDpiScaleFactorRoundingPolicy::RoundPreferFloor), 392},
    {sipName_RoundTile, static_cast<int>( ::Qt::RoundTile), 439},
    {sipName_SHIFT, static_cast<int>( ::Qt::SHIFT), 412},
    {sipName_Saturday, static_cast<int>( ::Qt::Saturday), 373},
    {sipName_ScrollBarAlwaysOff, static_cast<int>( ::Qt::ScrollBarAlwaysOff), 427},
    {sipName_ScrollBarAlwaysOn, static_cast<int>( ::Qt::ScrollBarAlwaysOn), 427},
    {sipName_ScrollBarAsNeeded, static_cast<int>( ::Qt::ScrollBarAsNeeded), 427},
    {sipName_ScrollBegin, static_cast<int>( ::Qt::ScrollBegin), 428},
    {sipName_ScrollEnd, static_cast<int>( ::Qt::ScrollEnd), 428},
    {sipName_ScrollMomentum, static_cast<int>( ::Qt::ScrollMomentum), 428},
    {sipName_ScrollUpdate, static_cast<int>( ::Qt::ScrollUpdate), 428},
    {sipName_Sheet, static_cast<int>( ::Qt::Sheet), 456},
    {sipName_ShiftModifier, static_cast<int>( ::Qt::ShiftModifier), 406},
    {sipName_ShortcutFocusReason, static_cast<int>( ::Qt::ShortcutFocusReason), 386},
    {sipName_SizeAllCursor, static_cast<int>( ::Qt::SizeAllCursor), 371},
    {sipName_SizeBDiagCursor, static_cast<int>( ::Qt::SizeBDiagCursor), 371},
    {sipName_SizeFDiagCursor, static_cast<int>( ::Qt::SizeFDiagCursor), 371},
    {sipName_SizeHintRole, static_cast<int>( ::Qt::SizeHintRole), 400},
    {sipName_SizeHorCursor, static_cast<int>( ::Qt::SizeHorCursor), 371},
    {sipName_SizeVerCursor, static_cast<int>( ::Qt::SizeVerCursor), 371},
    {sipName_SmartZoomNativeGesture, static_cast<int>( ::Qt::SmartZoomNativeGesture), 418},
    {sipName_SmoothTransformation, static_cast<int>( ::Qt::SmoothTransformation), 447},
    {sipName_SolidLine, static_cast<int>( ::Qt::SolidLine), 424},
    {sipName_SolidPattern, static_cast<int>( ::Qt::SolidPattern), 361},
    {sipName_SplashScreen, static_cast<int>( ::Qt::SplashScreen), 456},
    {sipName_SplitHCursor, static_cast<int>( ::Qt::SplitHCursor), 371},
    {sipName_SplitVCursor, static_cast<int>( ::Qt::SplitVCursor), 371},
    {sipName_SquareCap, static_cast<int>( ::Qt::SquareCap), 422},
    {sipName_StatusTipRole, static_cast<int>( ::Qt::StatusTipRole), 400},
    {sipName_StretchTile, static_cast<int>( ::Qt::StretchTile), 439},
    {sipName_StrongFocus, static_cast<int>( ::Qt::StrongFocus), 385},
    {sipName_SubWindow, static_cast<int>( ::Qt::SubWindow), 456},
    {sipName_Sunday, static_cast<int>( ::Qt::Sunday), 373},
    {sipName_SvgMiterJoin, static_cast<int>( ::Qt::SvgMiterJoin), 423},
    {sipName_SwipeGesture, static_cast<int>( ::Qt::SwipeGesture), 390},
    {sipName_SwipeNativeGesture, static_cast<int>( ::Qt::SwipeNativeGesture), 418},
    {sipName_SystemLocaleDate, static_cast<int>( ::Qt::SystemLocaleDate), 372},
    {sipName_SystemLocaleLongDate, static_cast<int>( ::Qt::SystemLocaleLongDate), 372},
    {sipName_SystemLocaleShortDate, static_cast<int>( ::Qt::SystemLocaleShortDate), 372},
    {sipName_TabFocus, static_cast<int>( ::Qt::TabFocus), 385},
    {sipName_TabFocusAllControls, static_cast<int>( ::Qt::TabFocusAllControls), 433},
    {sipName_TabFocusListControls, static_cast<int>( ::Qt::TabFocusListControls), 433},
    {sipName_TabFocusReason, static_cast<int>( ::Qt::TabFocusReason), 386},
    {sipName_TabFocusTextControls, static_cast<int>( ::Qt::TabFocusTextControls), 433},
    {sipName_TapAndHoldGesture, static_cast<int>( ::Qt::TapAndHoldGesture), 390},
    {sipName_TapGesture, static_cast<int>( ::Qt::TapGesture), 390},
    {sipName_TargetMoveAction, static_cast<int>( ::Qt::TargetMoveAction), 376},
    {sipName_TaskButton, static_cast<int>( ::Qt::TaskButton), 413},
    {sipName_TextAlignmentRole, static_cast<int>( ::Qt::TextAlignmentRole), 400},
    {sipName_TextBrowserInteraction, static_cast<int>( ::Qt::TextBrowserInteraction), 437},
    {sipName_TextColorRole, static_cast<int>( ::Qt::TextColorRole), 400},
    {sipName_TextDate, static_cast<int>( ::Qt::TextDate), 372},
    {sipName_TextDontClip, static_cast<int>( ::Qt::TextDontClip), 435},
    {sipName_TextDontPrint, static_cast<int>( ::Qt::TextDontPrint), 435},
    {sipName_TextEditable, static_cast<int>( ::Qt::TextEditable), 437},
    {sipName_TextEditorInteraction, static_cast<int>( ::Qt::TextEditorInteraction), 437},
    {sipName_TextExpandTabs, static_cast<int>( ::Qt::TextExpandTabs), 435},
    {sipName_TextHideMnemonic, static_cast<int>( ::Qt::TextHideMnemonic), 435},
    {sipName_TextIncludeTrailingSpaces, static_cast<int>( ::Qt::TextIncludeTrailingSpaces), 435},
    {sipName_TextJustificationForced, static_cast<int>( ::Qt::TextJustificationForced), 435},
    {sipName_TextSelectableByKeyboard, static_cast<int>( ::Qt::TextSelectableByKeyboard), 437},
    {sipName_TextSelectableByMouse, static_cast<int>( ::Qt::TextSelectableByMouse), 437},
    {sipName_TextShowMnemonic, static_cast<int>( ::Qt::TextShowMnemonic), 435},
    {sipName_TextSingleLine, static_cast<int>( ::Qt::TextSingleLine), 435},
    {sipName_TextWordWrap, static_cast<int>( ::Qt::TextWordWrap), 435},
    {sipName_TextWrapAnywhere, static_cast<int>( ::Qt::TextWrapAnywhere), 435},
    {sipName_TexturePattern, static_cast<int>( ::Qt::TexturePattern), 361},
    {sipName_ThresholdAlphaDither, static_cast<int>( ::Qt::ThresholdAlphaDither), 394},
    {sipName_ThresholdDither, static_cast<int>( ::Qt::ThresholdDither), 394},
    {sipName_Thursday, static_cast<int>( ::Qt::Thursday), 373},
    {sipName_TimeZone, static_cast<int>( ::Qt::TimeZone), 440},
    {sipName_TitleBarArea, static_cast<int>( ::Qt::TitleBarArea), 452},
    {sipName_Tool, static_cast<int>( ::Qt::Tool), 456},
    {sipName_ToolBarArea_Mask, static_cast<int>( ::Qt::ToolBarArea_Mask), 442},
    {sipName_ToolButtonFollowStyle, static_cast<int>( ::Qt::ToolButtonFollowStyle), 444},
    {sipName_ToolButtonIconOnly, static_cast<int>( ::Qt::ToolButtonIconOnly), 444},
    {sipName_ToolButtonTextBesideIcon, static_cast<int>( ::Qt::ToolButtonTextBesideIcon), 444},
    {sipName_ToolButtonTextOnly, static_cast<int>( ::Qt::ToolButtonTextOnly), 444},
    {sipName_ToolButtonTextUnderIcon, static_cast<int>( ::Qt::ToolButtonTextUnderIcon), 444},
    {sipName_ToolTip, static_cast<int>( ::Qt::ToolTip), 456},
    {sipName_ToolTipRole, static_cast<int>( ::Qt::ToolTipRole), 400},
    {sipName_TopDockWidgetArea, static_cast<int>( ::Qt::TopDockWidgetArea), 374},
    {sipName_TopEdge, static_cast<int>( ::Qt::TopEdge), 378},
    {sipName_TopLeftCorner, static_cast<int>( ::Qt::TopLeftCorner), 369},
    {sipName_TopLeftSection, static_cast<int>( ::Qt::TopLeftSection), 452},
    {sipName_TopRightCorner, static_cast<int>( ::Qt::TopRightCorner), 369},
    {sipName_TopRightSection, static_cast<int>( ::Qt::TopRightSection), 452},
    {sipName_TopSection, static_cast<int>( ::Qt::TopSection), 452},
    {sipName_TopToolBarArea, static_cast<int>( ::Qt::TopToolBarArea), 442},
    {sipName_TouchPointMoved, static_cast<int>( ::Qt::TouchPointMoved), 445},
    {sipName_TouchPointPressed, static_cast<int>( ::Qt::TouchPointPressed), 445},
    {sipName_TouchPointReleased, static_cast<int>( ::Qt::TouchPointReleased), 445},
    {sipName_TouchPointStationary, static_cast<int>( ::Qt::TouchPointStationary), 445},
    {sipName_TransparentMode, static_cast<int>( ::Qt::TransparentMode), 360},
    {sipName_Tuesday, static_cast<int>( ::Qt::Tuesday), 373},
    {sipName_UI_AnimateCombo, static_cast<int>( ::Qt::UI_AnimateCombo), 448},
    {sipName_UI_AnimateMenu, static_cast<int>( ::Qt::UI_AnimateMenu), 448},
    {sipName_UI_AnimateToolBox, static_cast<int>( ::Qt::UI_AnimateToolBox), 448},
    {sipName_UI_AnimateTooltip, static_cast<int>( ::Qt::UI_AnimateTooltip), 448},
    {sipName_UI_FadeMenu, static_cast<int>( ::Qt::UI_FadeMenu), 448},
    {sipName_UI_FadeTooltip, static_cast<int>( ::Qt::UI_FadeTooltip), 448},
    {sipName_UI_General, static_cast<int>( ::Qt::UI_General), 448},
    {sipName_UNICODE_ACCEL, static_cast<int>( ::Qt::UNICODE_ACCEL), 412},
    {sipName_UTC, static_cast<int>( ::Qt::UTC), 440},
    {sipName_Unchecked, static_cast<int>( ::Qt::Unchecked), 363},
    {sipName_UniqueConnection, static_cast<int>( ::Qt::UniqueConnection), 366},
    {sipName_UpArrow, static_cast<int>( ::Qt::UpArrow), 357},
    {sipName_UpArrowCursor, static_cast<int>( ::Qt::UpArrowCursor), 371},
    {sipName_UserRole, static_cast<int>( ::Qt::UserRole), 400},
    {sipName_VerPattern, static_cast<int>( ::Qt::VerPattern), 361},
    {sipName_Vertical, static_cast<int>( ::Qt::Vertical), 420},
    {sipName_VeryCoarseTimer, static_cast<int>( ::Qt::VeryCoarseTimer), 441},
    {sipName_VisualMoveStyle, static_cast<int>( ::Qt::VisualMoveStyle), 370},
    {sipName_WA_AcceptDrops, static_cast<int>( ::Qt::WA_AcceptDrops), 450},
    {sipName_WA_AcceptTouchEvents, static_cast<int>( ::Qt::WA_AcceptTouchEvents), 450},
    {sipName_WA_AlwaysShowToolTips, static_cast<int>( ::Qt::WA_AlwaysShowToolTips), 450},
    {sipName_WA_AlwaysStackOnTop, static_cast<int>( ::Qt::WA_AlwaysStackOnTop), 450},
    {sipName_WA_AttributeCount, static_cast<int>( ::Qt::WA_AttributeCount), 450},
    {sipName_WA_ContentsMarginsRespectsSafeArea, static_cast<int>( ::Qt::WA_ContentsMarginsRespectsSafeArea), 450},
    {sipName_WA_CustomWhatsThis, static_cast<int>( ::Qt::WA_CustomWhatsThis), 450},
    {sipName_WA_DeleteOnClose, static_cast<int>( ::Qt::WA_DeleteOnClose), 450},
    {sipName_WA_Disabled, static_cast<int>( ::Qt::WA_Disabled), 450},
    {sipName_WA_DontCreateNativeAncestors, static_cast<int>( ::Qt::WA_DontCreateNativeAncestors), 450},
    {sipName_WA_DontShowOnScreen, static_cast<int>( ::Qt::WA_DontShowOnScreen), 450},
    {sipName_WA_ForceDisabled, static_cast<int>( ::Qt::WA_ForceDisabled), 450},
    {sipName_WA_ForceUpdatesDisabled, static_cast<int>( ::Qt::WA_ForceUpdatesDisabled), 450},
    {sipName_WA_GrabbedShortcut, static_cast<int>( ::Qt::WA_GrabbedShortcut), 450},
    {sipName_WA_GroupLeader, static_cast<int>( ::Qt::WA_GroupLeader), 450},
    {sipName_WA_Hover, static_cast<int>( ::Qt::WA_Hover), 450},
    {sipName_WA_InputMethodEnabled, static_cast<int>( ::Qt::WA_InputMethodEnabled), 450},
    {sipName_WA_InputMethodTransparent, static_cast<int>( ::Qt::WA_InputMethodTransparent), 450},
    {sipName_WA_InvalidSize, static_cast<int>( ::Qt::WA_InvalidSize), 450},
    {sipName_WA_KeyCompression, static_cast<int>( ::Qt::WA_KeyCompression), 450},
    {sipName_WA_KeyboardFocusChange, static_cast<int>( ::Qt::WA_KeyboardFocusChange), 450},
    {sipName_WA_LaidOut, static_cast<int>( ::Qt::WA_LaidOut), 450},
    {sipName_WA_LayoutOnEntireRect, static_cast<int>( ::Qt::WA_LayoutOnEntireRect), 450},
    {sipName_WA_LayoutUsesWidgetRect, static_cast<int>( ::Qt::WA_LayoutUsesWidgetRect), 450},
    {sipName_WA_MSWindowsUseDirect3D, static_cast<int>( ::Qt::WA_MSWindowsUseDirect3D), 450},
    {sipName_WA_MacAlwaysShowToolWindow, static_cast<int>( ::Qt::WA_MacAlwaysShowToolWindow), 450},
    {sipName_WA_MacBrushedMetal, static_cast<int>( ::Qt::WA_MacBrushedMetal), 450},
    {sipName_WA_MacFrameworkScaled, static_cast<int>( ::Qt::WA_MacFrameworkScaled), 450},
    {sipName_WA_MacMetalStyle, static_cast<int>( ::Qt::WA_MacMetalStyle), 450},
    {sipName_WA_MacMiniSize, static_cast<int>( ::Qt::WA_MacMiniSize), 450},
    {sipName_WA_MacNoClickThrough, static_cast<int>( ::Qt::WA_MacNoClickThrough), 450},
    {sipName_WA_MacNoShadow, static_cast<int>( ::Qt::WA_MacNoShadow), 450},
    {sipName_WA_MacNormalSize, static_cast<int>( ::Qt::WA_MacNormalSize), 450},
    {sipName_WA_MacOpaqueSizeGrip, static_cast<int>( ::Qt::WA_MacOpaqueSizeGrip), 450},
    {sipName_WA_MacShowFocusRect, static_cast<int>( ::Qt::WA_MacShowFocusRect), 450},
    {sipName_WA_MacSmallSize, static_cast<int>( ::Qt::WA_MacSmallSize), 450},
    {sipName_WA_MacVariableSize, static_cast<int>( ::Qt::WA_MacVariableSize), 450},
    {sipName_WA_Mapped, static_cast<int>( ::Qt::WA_Mapped), 450},
    {sipName_WA_MouseNoMask, static_cast<int>( ::Qt::WA_MouseNoMask), 450},
    {sipName_WA_MouseTracking, static_cast<int>( ::Qt::WA_MouseTracking), 450},
    {sipName_WA_Moved, static_cast<int>( ::Qt::WA_Moved), 450},
    {sipName_WA_NativeWindow, static_cast<int>( ::Qt::WA_NativeWindow), 450},
    {sipName_WA_NoChildEventsForParent, static_cast<int>( ::Qt::WA_NoChildEventsForParent), 450},
    {sipName_WA_NoChildEventsFromChildren, static_cast<int>( ::Qt::WA_NoChildEventsFromChildren), 450},
    {sipName_WA_NoMousePropagation, static_cast<int>( ::Qt::WA_NoMousePropagation), 450},
    {sipName_WA_NoMouseReplay, static_cast<int>( ::Qt::WA_NoMouseReplay), 450},
    {sipName_WA_NoSystemBackground, static_cast<int>( ::Qt::WA_NoSystemBackground), 450},
    {sipName_WA_NoX11EventCompression, static_cast<int>( ::Qt::WA_NoX11EventCompression), 450},
    {sipName_WA_OpaquePaintEvent, static_cast<int>( ::Qt::WA_OpaquePaintEvent), 450},
    {sipName_WA_OutsideWSRange, static_cast<int>( ::Qt::WA_OutsideWSRange), 450},
    {sipName_WA_PaintOnScreen, static_cast<int>( ::Qt::WA_PaintOnScreen), 450},
    {sipName_WA_PaintUnclipped, static_cast<int>( ::Qt::WA_PaintUnclipped), 450},
    {sipName_WA_PendingMoveEvent, static_cast<int>( ::Qt::WA_PendingMoveEvent), 450},
    {sipName_WA_PendingResizeEvent, static_cast<int>( ::Qt::WA_PendingResizeEvent), 450},
    {sipName_WA_PendingUpdate, static_cast<int>( ::Qt::WA_PendingUpdate), 450},
    {sipName_WA_QuitOnClose, static_cast<int>( ::Qt::WA_QuitOnClose), 450},
    {sipName_WA_Resized, static_cast<int>( ::Qt::WA_Resized), 450},
    {sipName_WA_RightToLeft, static_cast<int>( ::Qt::WA_RightToLeft), 450},
    {sipName_WA_SetCursor, static_cast<int>( ::Qt::WA_SetCursor), 450},
    {sipName_WA_SetFont, static_cast<int>( ::Qt::WA_SetFont), 450},
    {sipName_WA_SetLayoutDirection, static_cast<int>( ::Qt::WA_SetLayoutDirection), 450},
    {sipName_WA_SetLocale, static_cast<int>( ::Qt::WA_SetLocale), 450},
    {sipName_WA_SetPalette, static_cast<int>( ::Qt::WA_SetPalette), 450},
    {sipName_WA_SetStyle, static_cast<int>( ::Qt::WA_SetStyle), 450},
    {sipName_WA_SetWindowIcon, static_cast<int>( ::Qt::WA_SetWindowIcon), 450},
    {sipName_WA_ShowWithoutActivating, static_cast<int>( ::Qt::WA_ShowWithoutActivating), 450},
    {sipName_WA_StaticContents, static_cast<int>( ::Qt::WA_StaticContents), 450},
    {sipName_WA_StyleSheet, static_cast<int>( ::Qt::WA_StyleSheet), 450},
    {sipName_WA_StyleSheetTarget, static_cast<int>( ::Qt::WA_StyleSheetTarget), 450},
    {sipName_WA_StyledBackground, static_cast<int>( ::Qt::WA_StyledBackground), 450},
    {sipName_WA_TabletTracking, static_cast<int>( ::Qt::WA_TabletTracking), 450},
    {sipName_WA_TintedBackground, static_cast<int>( ::Qt::WA_TintedBackground), 450},
    {sipName_WA_TouchPadAcceptSingleTouchEvents, static_cast<int>( ::Qt::WA_TouchPadAcceptSingleTouchEvents), 450},
    {sipName_WA_TranslucentBackground, static_cast<int>( ::Qt::WA_TranslucentBackground), 450},
    {sipName_WA_TransparentForMouseEvents, static_cast<int>( ::Qt::WA_TransparentForMouseEvents), 450},
    {sipName_WA_UnderMouse, static_cast<int>( ::Qt::WA_UnderMouse), 450},
    {sipName_WA_UpdatesDisabled, static_cast<int>( ::Qt::WA_UpdatesDisabled), 450},
    {sipName_WA_WState_CompressKeys, static_cast<int>( ::Qt::WA_WState_CompressKeys), 450},
    {sipName_WA_WState_ConfigPending, static_cast<int>( ::Qt::WA_WState_ConfigPending), 450},
    {sipName_WA_WState_Created, static_cast<int>( ::Qt::WA_WState_Created), 450},
    {sipName_WA_WState_ExplicitShowHide, static_cast<int>( ::Qt::WA_WState_ExplicitShowHide), 450},
    {sipName_WA_WState_Hidden, static_cast<int>( ::Qt::WA_WState_Hidden), 450},
    {sipName_WA_WState_InPaintEvent, static_cast<int>( ::Qt::WA_WState_InPaintEvent), 450},
    {sipName_WA_WState_OwnSizePolicy, static_cast<int>( ::Qt::WA_WState_OwnSizePolicy), 450},
    {sipName_WA_WState_Polished, static_cast<int>( ::Qt::WA_WState_Polished), 450},
    {sipName_WA_WState_Reparented, static_cast<int>( ::Qt::WA_WState_Reparented), 450},
    {sipName_WA_WState_Visible, static_cast<int>( ::Qt::WA_WState_Visible), 450},
    {sipName_WA_WindowModified, static_cast<int>( ::Qt::WA_WindowModified), 450},
    {sipName_WA_WindowPropagation, static_cast<int>( ::Qt::WA_WindowPropagation), 450},
    {sipName_WA_X11DoNotAcceptFocus, static_cast<int>( ::Qt::WA_X11DoNotAcceptFocus), 450},
    {sipName_WA_X11NetWmWindowTypeCombo, static_cast<int>( ::Qt::WA_X11NetWmWindowTypeCombo), 450},
    {sipName_WA_X11NetWmWindowTypeDND, static_cast<int>( ::Qt::WA_X11NetWmWindowTypeDND), 450},
    {sipName_WA_X11NetWmWindowTypeDesktop, static_cast<int>( ::Qt::WA_X11NetWmWindowTypeDesktop), 450},
    {sipName_WA_X11NetWmWindowTypeDialog, static_cast<int>( ::Qt::WA_X11NetWmWindowTypeDialog), 450},
    {sipName_WA_X11NetWmWindowTypeDock, static_cast<int>( ::Qt::WA_X11NetWmWindowTypeDock), 450},
    {sipName_WA_X11NetWmWindowTypeDropDownMenu, static_cast<int>( ::Qt::WA_X11NetWmWindowTypeDropDownMenu), 450},
    {sipName_WA_X11NetWmWindowTypeMenu, static_cast<int>( ::Qt::WA_X11NetWmWindowTypeMenu), 450},
    {sipName_WA_X11NetWmWindowTypeNotification, static_cast<int>( ::Qt::WA_X11NetWmWindowTypeNotification), 450},
    {sipName_WA_X11NetWmWindowTypePopupMenu, static_cast<int>( ::Qt::WA_X11NetWmWindowTypePopupMenu), 450},
    {sipName_WA_X11NetWmWindowTypeSplash, static_cast<int>( ::Qt::WA_X11NetWmWindowTypeSplash), 450},
    {sipName_WA_X11NetWmWindowTypeToolBar, static_cast<int>( ::Qt::WA_X11NetWmWindowTypeToolBar), 450},
    {sipName_WA_X11NetWmWindowTypeToolTip, static_cast<int>( ::Qt::WA_X11NetWmWindowTypeToolTip), 450},
    {sipName_WA_X11NetWmWindowTypeUtility, static_cast<int>( ::Qt::WA_X11NetWmWindowTypeUtility), 450},
    {sipName_WA_X11OpenGLOverlay, static_cast<int>( ::Qt::WA_X11OpenGLOverlay), 450},
    {sipName_WaitCursor, static_cast<int>( ::Qt::WaitCursor), 371},
    {sipName_Wednesday, static_cast<int>( ::Qt::Wednesday), 373},
    {sipName_WhatsThisCursor, static_cast<int>( ::Qt::WhatsThisCursor), 371},
    {sipName_WhatsThisRole, static_cast<int>( ::Qt::WhatsThisRole), 400},
    {sipName_WheelFocus, static_cast<int>( ::Qt::WheelFocus), 385},
    {sipName_WhiteSpaceModeUndefined, static_cast<int>( ::Qt::WhiteSpaceModeUndefined), 449},
    {sipName_WhiteSpaceNoWrap, static_cast<int>( ::Qt::WhiteSpaceNoWrap), 449},
    {sipName_WhiteSpaceNormal, static_cast<int>( ::Qt::WhiteSpaceNormal), 449},
    {sipName_WhiteSpacePre, static_cast<int>( ::Qt::WhiteSpacePre), 449},
    {sipName_Widget, static_cast<int>( ::Qt::Widget), 456},
    {sipName_WidgetShortcut, static_cast<int>( ::Qt::WidgetShortcut), 429},
    {sipName_WidgetWithChildrenShortcut, static_cast<int>( ::Qt::WidgetWithChildrenShortcut), 429},
    {sipName_WindingFill, static_cast<int>( ::Qt::WindingFill), 382},
    {sipName_Window, static_cast<int>( ::Qt::Window), 456},
    {sipName_WindowActive, static_cast<int>( ::Qt::WindowActive), 454},
    {sipName_WindowCloseButtonHint, static_cast<int>( ::Qt::WindowCloseButtonHint), 456},
    {sipName_WindowContextHelpButtonHint, static_cast<int>( ::Qt::WindowContextHelpButtonHint), 456},
    {sipName_WindowDoesNotAcceptFocus, static_cast<int>( ::Qt::WindowDoesNotAcceptFocus), 456},
    {sipName_WindowFullScreen, static_cast<int>( ::Qt::WindowFullScreen), 454},
    {sipName_WindowFullscreenButtonHint, static_cast<int>( ::Qt::WindowFullscreenButtonHint), 456},
    {sipName_WindowMaximizeButtonHint, static_cast<int>( ::Qt::WindowMaximizeButtonHint), 456},
    {sipName_WindowMaximized, static_cast<int>( ::Qt::WindowMaximized), 454},
    {sipName_WindowMinMaxButtonsHint, static_cast<int>( ::Qt::WindowMinMaxButtonsHint), 456},
    {sipName_WindowMinimizeButtonHint, static_cast<int>( ::Qt::WindowMinimizeButtonHint), 456},
    {sipName_WindowMinimized, static_cast<int>( ::Qt::WindowMinimized), 454},
    {sipName_WindowModal, static_cast<int>( ::Qt::WindowModal), 453},
    {sipName_WindowNoState, static_cast<int>( ::Qt::WindowNoState), 454},
    {sipName_WindowOverridesSystemGestures, static_cast<int>( ::Qt::WindowOverridesSystemGestures), 456},
    {sipName_WindowShadeButtonHint, static_cast<int>( ::Qt::WindowShadeButtonHint), 456},
    {sipName_WindowShortcut, static_cast<int>( ::Qt::WindowShortcut), 429},
    {sipName_WindowStaysOnBottomHint, static_cast<int>( ::Qt::WindowStaysOnBottomHint), 456},
    {sipName_WindowStaysOnTopHint, static_cast<int>( ::Qt::WindowStaysOnTopHint), 456},
    {sipName_WindowSystemMenuHint, static_cast<int>( ::Qt::WindowSystemMenuHint), 456},
    {sipName_WindowTitleHint, static_cast<int>( ::Qt::WindowTitleHint), 456},
    {sipName_WindowTransparentForInput, static_cast<int>( ::Qt::WindowTransparentForInput), 456},
    {sipName_WindowType_Mask, static_cast<int>( ::Qt::WindowType_Mask), 456},
    {sipName_X11BypassWindowManagerHint, static_cast<int>( ::Qt::X11BypassWindowManagerHint), 456},
    {sipName_XAxis, static_cast<int>( ::Qt::XAxis), 359},
    {sipName_XButton1, static_cast<int>( ::Qt::XButton1), 413},
    {sipName_XButton2, static_cast<int>( ::Qt::XButton2), 413},
    {sipName_YAxis, static_cast<int>( ::Qt::YAxis), 359},
    {sipName_ZAxis, static_cast<int>( ::Qt::ZAxis), 359},
    {sipName_ZoomNativeGesture, static_cast<int>( ::Qt::ZoomNativeGesture), 418},
    {sipName_black, static_cast<int>( ::Qt::black), 391},
    {sipName_blue, static_cast<int>( ::Qt::blue), 391},
    {sipName_color0, static_cast<int>( ::Qt::color0), 391},
    {sipName_color1, static_cast<int>( ::Qt::color1), 391},
    {sipName_cyan, static_cast<int>( ::Qt::cyan), 391},
    {sipName_darkBlue, static_cast<int>( ::Qt::darkBlue), 391},
    {sipName_darkCyan, static_cast<int>( ::Qt::darkCyan), 391},
    {sipName_darkGray, static_cast<int>( ::Qt::darkGray), 391},
    {sipName_darkGreen, static_cast<int>( ::Qt::darkGreen), 391},
    {sipName_darkMagenta, static_cast<int>( ::Qt::darkMagenta), 391},
    {sipName_darkRed, static_cast<int>( ::Qt::darkRed), 391},
    {sipName_darkYellow, static_cast<int>( ::Qt::darkYellow), 391},
    {sipName_gray, static_cast<int>( ::Qt::gray), 391},
    {sipName_green, static_cast<int>( ::Qt::green), 391},
    {sipName_lightGray, static_cast<int>( ::Qt::lightGray), 391},
    {sipName_magenta, static_cast<int>( ::Qt::magenta), 391},
    {sipName_red, static_cast<int>( ::Qt::red), 391},
    {sipName_transparent, static_cast<int>( ::Qt::transparent), 391},
    {sipName_white, static_cast<int>( ::Qt::white), 391},
    {sipName_yellow, static_cast<int>( ::Qt::yellow), 391},
};


static pyqt5ClassPluginDef plugin_Qt = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtCore_Qt = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_NAMESPACE,
        sipNameNr_Qt,
        {SIP_NULLPTR},
        &plugin_Qt
    },
    {
        sipNameNr_Qt,
        {0, 0, 1},
        0, SIP_NULLPTR,
        1162, enummembers_Qt,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
